@@ -84,23 +84,23 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
 
     //Menu
     KAction* opennew = KStandardAction::openNew(this, SLOT(actionNew()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("file_new", opennew);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("file_new", opennew);
 
     KAction* open = KStandardAction::open(this, SLOT(actionOpen()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("file_open", open);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("file_open", open);
 
     m_saveAction = KStandardAction::save(this, SLOT(actionSave()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("file_save", m_saveAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("file_save", m_saveAction);
 
     m_saveAsAction = KStandardAction::saveAs(this, SLOT(actionSaveAs()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("file_save_as", m_saveAsAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("file_save_as", m_saveAsAction);
 
     m_passwordAction = new KAction(KIcon("document-encrypt"),  i18nc("Action allowing the user to change his document password", "Change password..."), this);
     connect(m_passwordAction, SIGNAL(triggered(bool)), this, SLOT(actionChangePassword()));
     actionCollection()->addAction(QLatin1String("file_change_password"), m_passwordAction);
     m_passwordAction->setShortcut(Qt::CTRL + Qt::Key_K);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("file_change_password", m_passwordAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("file_change_password", m_passwordAction);
 
     //Recent file
     m_recentFiles = KStandardAction::openRecent(this, SLOT(actionOpen(KUrl)), actionCollection());
