@@ -81,7 +81,7 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     connect(m_undoSaveAction, SIGNAL(triggered(bool)), this, SLOT(actionUndoSave()));
     actionCollection()->addAction(QLatin1String("edit_undolastsave"), m_undoSaveAction);
     m_undoSaveAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_Z);
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_undolastsave", m_undoSaveAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_undolastsave", m_undoSaveAction);
 
     m_undoAction = new KToolBarPopupAction(KIcon("edit-undo"), i18nc("Verb, action to cancel previous action", "Undo"), this);
     connect(m_undoAction, SIGNAL(triggered(bool)), this, SLOT(actionUndo()));
@@ -95,7 +95,7 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     m_undoAction->setData(1);
 
     //undoAction=KStandardAction::undo(this, SLOT(actionUndo()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit-undo", m_undoAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit-undo", m_undoAction);
 
     m_redoAction = new KToolBarPopupAction(KIcon("edit-redo"), i18nc("Verb, action to redo previous cancelled action", "Redo"), this);
     connect(m_redoAction, SIGNAL(triggered(bool)), this, SLOT(actionRedo()));
@@ -108,7 +108,7 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     m_redoAction->setData(1);
 
     //redoAction=KStandardAction::redo(this, SLOT(actionRedo()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit-redo", m_redoAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit-redo", m_redoAction);
 
     // add action to control hide / display of history
     m_dockWidget->toggleViewAction()->setShortcut(Qt::SHIFT + Qt::Key_F11);
