@@ -75,14 +75,12 @@ SKGError SKGImportPluginGnc::importFile()
     if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginGnc::importFile(", err);
-    QString iFileName = m_importer->getFileName();
-    SKGTRACEL(10) << "Input filename=" << iFileName << endl;
 
     //Open file
-    QIODevice* file = KFilterDev::deviceForFile(iFileName, "application/x-gzip");
+    QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
     if (!file->open(QIODevice::ReadOnly)) {
         err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Open file '%1' failed", iFileName));
+        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
     } else {
         QDomDocument doc;
 
@@ -97,7 +95,7 @@ SKGError SKGImportPluginGnc::importFile()
             err.setReturnCode(ERR_ABORT);
             err.setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
 
-            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", iFileName));
+            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName()));
         } else {
             //Get root
             QDomElement docElem = doc.documentElement();
