@@ -65,8 +65,6 @@ SKGError SKGImportPluginOfx::importFile()
 
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginOfx::importFile", err);
-    QString iFileName = m_importer->getFileName();
-    SKGTRACEL(10) << "Input filename=" << iFileName << endl;
 
     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "OFX"));
     if (!err) {
@@ -80,8 +78,8 @@ SKGError SKGImportPluginOfx::importFile()
             ofx_set_statement_cb(ctx, SKGImportPluginOfx::ofxStatementCallback, m_importer);
             ofx_set_transaction_cb(ctx, SKGImportPluginOfx::ofxTransactionCallback, m_importer);
             //ofx_set_security_cb(ctx, ofxSecurityCallback, this);
-            int rc = libofx_proc_file(ctx, iFileName.toUtf8(), AUTODETECT);
-            if (rc)  err = SKGError(ERR_FAIL, i18nc("Error message",  "Import OFX file '%1' failed", iFileName));
+            int rc = libofx_proc_file(ctx, m_importer->getLocalFileName().toUtf8(), AUTODETECT);
+            if (rc)  err = SKGError(ERR_FAIL, i18nc("Error message",  "Import OFX file '%1' failed", m_importer->getFileName()));
             if (!err) err = SKGImportPluginOfx::m_ofxError;
             {
                 //This is an option ==> no error management
