@@ -64,15 +64,13 @@ SKGError SKGImportPluginXhb::importFile()
     if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginXhb::importFile", err);
-    QString iFileName = m_importer->getFileName();
-    SKGTRACEL(10) << "Input filename=" << iFileName << endl;
 
     //Initialisation
     //Open file
-    QIODevice* file = KFilterDev::deviceForFile(iFileName, "application/x-gzip");
+    QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
     if (!file->open(QIODevice::ReadOnly)) {
         err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Open file '%1' failed", iFileName));
+        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
     } else {
         QDomDocument doc;
 
@@ -93,7 +91,7 @@ SKGError SKGImportPluginXhb::importFile()
 
 
         if (!contentOK) {
-            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", iFileName));
+            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName()));
         } else {
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "XHB"), 4);
 
