@@ -144,16 +144,18 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
 
     //Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
+        ui.kView->getView()->insertGlobalAction();
+        ui.kView->getView()->insertGlobalAction("open");
+        ui.kView->getView()->insertGlobalAction("open_report");
+        ui.kView->getView()->insertGlobalAction("edit_find");
+        ui.kView->getView()->insertGlobalAction();
         ui.kView->getView()->insertGlobalAction("edit_delete");
         ui.kView->getView()->insertGlobalAction();
         ui.kView->getView()->insertGlobalAction("edit_switch_highlight");
         ui.kView->getView()->insertGlobalAction("edit_reconciliate");
-        ui.kView->getView()->insertGlobalAction();
-        ui.kView->getView()->insertGlobalAction("edit_find");
-        ui.kView->getView()->insertGlobalAction("open_report");
     }
     connect(ui.kView->getView(), SIGNAL(clickEmptyArea()), this, SLOT(cleanEditor()));
-    connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onDoubleClickedAccount()));
+    connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
     //Search file list
@@ -351,7 +353,7 @@ void SKGBankPluginWidget::onIconChanged()
 
     int c = ui.kAccountCreatorIcon->currentIndex();
     if (c && c == ui.kAccountCreatorIcon->count() - 1) {
-        QString fileName = KFileDialog::getOpenFileName(KUrl(KStandardDirs::locate("data", "skrooge / images / logo / ")), "image / png image / jpeg image / gif image / tiff" , this);
+        QString fileName = KFileDialog::getOpenFileName(KUrl(KStandardDirs::locate("data", "skrooge/images/logo/")), "image/png image/jpeg image/gif image/tiff" , this);
         if (!fileName.isEmpty()) {
             if (ui.kAccountCreatorIcon->contains(fileName)) ui.kAccountCreatorIcon->setText(fileName);
             else {
@@ -579,30 +581,6 @@ void SKGBankPluginWidget::onModifyAccountClicked()
     SKGMainPanel::displayErrorMessage(err);
 }
 
-void SKGBankPluginWidget::onDoubleClickedAccount()
-{
-    SKGTRACEIN(10, "SKGBankPluginWidget::onDoubleClickedAccount");
-
-    //Open in operation plugin
-    SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
-    int nb = selection.count();
-    for (int i = 0; i < nb; ++i) {
-        SKGAccountObject accountObj = selection[i];
-
-        QDomDocument doc("SKGML");
-        doc.setContent(getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
-        QDomElement root = doc.documentElement();
-        if (root.isNull()) {
-            root = doc.createElement("parameters");
-            doc.appendChild(root);
-        }
-
-        root.setAttribute("account", accountObj.getName());
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
-
-    }
-}
-
 void SKGBankPluginWidget::onComputeRIB()
 {
     QString sb = ui.kAccountCreatorBankNumber->text().rightJustified(5, '0', true);
