@@ -68,14 +68,14 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGDocumentBank* iDocument)
     //Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
         ui.kCategoriesView->getView()->insertGlobalAction();
-
+        ui.kCategoriesView->getView()->insertGlobalAction("open");
+        ui.kCategoriesView->getView()->insertGlobalAction("open_report");
+        ui.kCategoriesView->getView()->insertGlobalAction("edit_find");
+        ui.kCategoriesView->getView()->insertGlobalAction();
         ui.kCategoriesView->getView()->insertGlobalAction("edit_delete");
         ui.kCategoriesView->getView()->insertGlobalAction();
         ui.kCategoriesView->getView()->insertGlobalAction("edit_switch_highlight");
         ui.kCategoriesView->getView()->insertGlobalAction();
-        ui.kCategoriesView->getView()->insertGlobalAction("edit_find");
-        ui.kCategoriesView->getView()->insertGlobalAction("open_report");
-        ui.kCategoriesView->getView()->insertGlobalAction();
 
         QStringList overlaycategories;
         overlaycategories.push_back("skrooge_category");
@@ -89,7 +89,7 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGDocumentBank* iDocument)
 
     connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     connect(ui.kCategoriesView->getView(), SIGNAL(clickEmptyArea()), this, SLOT(cleanEditor()));
-    connect(ui.kCategoriesView->getView(), SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onDoubleClick()));
+    connect(ui.kCategoriesView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kCategoriesView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
     //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
@@ -315,59 +315,6 @@ void SKGCategoriesPluginWidget::onDeleteUnused()
     if (act) act->trigger();
 }
 
-void SKGCategoriesPluginWidget::onDoubleClick()
-{
-    _SKGTRACEIN(10, "SKGCategoriesPluginWidget::onDoubleClick");
-
-    //Get selection
-    SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
-    if (selection.count() == 1) {
-        SKGCategoryObject cat(selection.at(0));
-        QString name = cat.getFullName();
-
-        //Build where clause and title
-        QString wc = "t_REALCATEGORY";
-        QString title;
-        if (name.isEmpty()) {
-            wc += " IS NULL OR t_REALCATEGORY=''";
-            wc = '(' % wc % ')';
-            title = i18nc("Noun, a list of items", "Sub operations with empty category");
-        } else {
-            wc += " = '" % SKGServices::stringToSqlString(name) % "' OR t_REALCATEGORY like '" % SKGServices::stringToSqlString(name) % OBJECTSEPARATOR % "%'";
-            wc = '(' % wc % ')';
-            title = i18nc("Noun, a list of items", "Sub operations with category containing '%1'",  name);
-        }
-
-        //Open
-        if (QApplication::keyboardModifiers() &Qt::ControlModifier && QApplication::keyboardModifiers() &Qt::ShiftModifier) {
-            //Call debug plugin
-            QDomDocument doc("SKGML");
-            QDomElement root = doc.createElement("parameters");
-            doc.appendChild(root);
-            root.setAttribute("sqlOrder", "SELECT * from v_operation_consolidated WHERE " % wc);
-
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Debug plugin"), -1, doc.toString());
-        } else {
-            //Call operation plugin
-            QDomDocument doc("SKGML");
-            doc.setContent(getDocument()->getParameter("SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS"));
-            QDomElement root = doc.documentElement();
-            if (root.isNull()) {
-                root = doc.createElement("parameters");
-                doc.appendChild(root);
-            }
-
-            root.setAttribute("operationTable", "v_operation_consolidated");
-            root.setAttribute("operationWhereClause", wc);
-            root.setAttribute("title", title);
-            root.setAttribute("title_icon", "skrooge_category");
-            root.setAttribute("currentPage", "-1");
-
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
-        }
-    }
-}
-
 void SKGCategoriesPluginWidget::cleanEditor()
 {
     if (getNbSelectedObjects() == 0) {
