@@ -95,7 +95,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     imports->addAction(m_importAction);
     m_importAction->setShortcut(Qt::CTRL + Qt::META + Qt::Key_I);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("import_operation", m_importAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("import_operation", m_importAction);
 
     //Import CSV Unit
     QStringList overlaycsv;
@@ -105,7 +105,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     actionCollection()->addAction(QLatin1String("import_csv_unit"), m_importCsvUnitAction);
     imports->addAction(m_importCsvUnitAction);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("import_csv_unit", m_importCsvUnitAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("import_csv_unit", m_importCsvUnitAction);
 
     //Exports
     KActionMenu* exports = new  KActionMenu(KIcon("document-export"), i18nc("Verb, action to export items in another format", "Export"), this);
@@ -118,7 +118,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     exports->addAction(m_exportFileAction);
     m_exportFileAction->setShortcut(Qt::CTRL + Qt::META + Qt::Key_E);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("export_operation", m_exportFileAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("export_operation", m_exportFileAction);
 
     //Processing
     KActionMenu* processing = new  KActionMenu(KIcon("tools-wizard"), i18nc("Noun, apply some kind of transformation on an item", "Processing"), this);
@@ -134,14 +134,14 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     processing->addAction(m_processingFoundTransfert);
     m_processingFoundTransfert->setShortcut(Qt::CTRL + Qt::META + Qt::Key_G);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("process_foundtransfer", m_processingFoundTransfert);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("process_foundtransfer", m_processingFoundTransfert);
 
     m_processingAnonymize = new KAction(KIcon("tools-wizard", NULL, overlaytransfers), i18nc("Verb, action to anonymize a document", "Anonymize"), this);
     connect(m_processingAnonymize, SIGNAL(triggered(bool)), SLOT(anonymize()));
     actionCollection()->addAction(QLatin1String("process_anonymize"), m_processingAnonymize);
     processing->addAction(m_processingAnonymize);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("process_anonymize", m_processingAnonymize);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("process_anonymize", m_processingAnonymize);
 
     //Processing banks
     m_processingBank = new KAction(KIcon("tools-wizard"), i18nc("Verb, action to clean an import", "Clean bank's imports"), this);
@@ -149,7 +149,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     actionCollection()->addAction(QLatin1String("process_banks"), m_processingBank);
     processing->addAction(m_processingBank);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("process_banks", m_processingBank);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("process_banks", m_processingBank);
 
     //Processing banks
     QStringList overlayValidate;
@@ -159,7 +159,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     actionCollection()->addAction(QLatin1String("validate_imported_operation"), m_validateImportedOperationsAction);
     m_validateImportedOperationsAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_V);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("validate_imported_operation", m_validateImportedOperationsAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("validate_imported_operation", m_validateImportedOperationsAction);
 
     QStringList overlayopen;
     overlayopen.push_back("skg_open");
@@ -168,14 +168,14 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     actionCollection()->addAction(QLatin1String("view_open_not_validated"), m_openNotValidatedAction);
     m_openNotValidatedAction->setShortcut(Qt::META + Qt::Key_V);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("view_open_not_validated", m_openNotValidatedAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("view_open_not_validated", m_openNotValidatedAction);
 
     m_mergeImportedOperationAction = new KAction(KIcon("merge"), i18nc("Verb, action to merge", "Merge imported operations"), this);
     connect(m_mergeImportedOperationAction, SIGNAL(triggered(bool)), SLOT(mergeImportedOperation()));
     actionCollection()->addAction(QLatin1String("merge_imported_operation"), m_mergeImportedOperationAction);
     m_mergeImportedOperationAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_M);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("merge_imported_operation", m_mergeImportedOperationAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("merge_imported_operation", m_mergeImportedOperationAction);
 
     //Get last argument
     connect(this, SIGNAL(importFile(QString)), this, SLOT(import(QString)), Qt::QueuedConnection);
@@ -297,11 +297,11 @@ void SKGImportExportPlugin::import(const QString& iFile)
 
         if (iFile.isEmpty()) {
             //Panel to ask files
-            KEncodingFileDialog::Result result = KEncodingFileDialog::getOpenFileNamesAndEncoding(lastCodecUsed, "kfiledialog:///IMPEXP",
+            KEncodingFileDialog::Result result = KEncodingFileDialog::getOpenUrlsAndEncoding(lastCodecUsed, "kfiledialog:///IMPEXP",
                                                  sender() == m_importCsvUnitAction ? QString("*.csv|" % i18nc("A file format", "CSV Files")) :
                                                  SKGImportExportManager::getImportMimeTypeFilter(),
                                                  SKGMainPanel::getMainPanel());
-            fileNames = result.fileNames;
+            fileNames = result.URLs.toStringList();
             codec = result.encoding;
         } else {
             fileNames.push_back(iFile);
@@ -615,8 +615,6 @@ void SKGImportExportPlugin::openNotValidated() const
         doc.appendChild(root);
     }
 
-    root.setAttribute("account", i18nc("For all accounts", "All"));
-    root.setAttribute("operationTable", "v_operation_display");
     root.setAttribute("operationWhereClause", wc);
     root.setAttribute("title", title);
     root.setAttribute("title_icon", icon());
@@ -674,9 +672,10 @@ SKGAdviceList SKGImportExportPlugin::advices() const
                 autoCorrections.push_back(i18nc("Advice on making the best (action)", "Remove operation"));
                 ad.setAutoCorrections(autoCorrections);
                 output.push_back(ad);
+
+                //Close file
+                file.close();
             }
-            //Close file
-            file.close();
         }
     }
     return output;
@@ -716,7 +715,9 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
         if (iSolution < listAccounts.count()) {
             //Addition in an account
 
-            if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+            if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                err = SKGError(ERR_FAIL, i18nc("An erro message", "Open file '%1' failed", fileName));
+            } else {
                 QTextStream stream(&file);
                 QString action = stream.readLine().trimmed();
                 QDate date = SKGServices::stringToTime(stream.readLine().trimmed()).date();
@@ -770,9 +771,10 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
                     imp1.setAutomaticApplyRules(automatic_rule);
                     err = imp1.finalizedImportedOperations();
                 }
+
+                //Close file
+                file.close();
             }
-            //Close file
-            file.close();
 
             //status bar
             if (!err) {
