@@ -74,11 +74,10 @@ SKGMonthlyPluginWidget::SKGMonthlyPluginWidget(SKGDocument* iDocument)
     ui.kDeleteTemplate->hide();
 
     //Make needed paths
-    QString path = QDir::homePath() % "/.kde/share/apps/skrooge/html/default/";
-    QDir().mkpath(path);
+    QString path = KStandardDirs::locateLocal("data", QString::fromLatin1("skrooge/html/default/"));
 
     //Copy "default" directory in locale
-    foreach(const QString & file, KStandardDirs().findAllResources("data", QString::fromLatin1("skrooge/html/default/*.txt"))) {
+    foreach(const QString & file, KStandardDirs().findAllResources("data", QString::fromLatin1("skrooge/html/default/*.html"))) {
         QFile(file).copy(path % QFileInfo(file).fileName());
     }
 
@@ -653,10 +652,6 @@ QString SKGMonthlyPluginWidget::getReport()
 
             //Prepare grantlee engine
             Grantlee::Engine gEngine(this);
-            QStringList kdeDataDirs = KGlobal::dirs()->findDirs("data", "skrooge/plugins/");
-            foreach(const QString & path, kdeDataDirs) {
-                gEngine.addPluginPath(path);
-            }
             gEngine.addDefaultLibrary("grantlee_skroogefilters");
 
             Grantlee::FileSystemTemplateLoader::Ptr gLoader = Grantlee::FileSystemTemplateLoader::Ptr(new Grantlee::FileSystemTemplateLoader());
