@@ -26,7 +26,10 @@
 #include "skgtraces.h"
 #include "skgoperationobject.h"
 #include "skgaccountobject.h"
+#include "skgtrackerobject.h"
+#include "skgbudgetobject.h"
 #include "skgsuboperationobject.h"
+#include "skgrecurrentoperationobject.h"
 #include "skgcategoryobject.h"
 #include "skgpayeeobject.h"
 #include "skgtransactionmng.h"
@@ -70,6 +73,7 @@ SKGOperationPlugin::~SKGOperationPlugin()
     m_openSuboperations = NULL;
     m_openDuplicate = NULL;
     m_mergeOperationAction = NULL;
+    m_open = NULL;
 }
 
 bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -91,7 +95,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     actionCollection()->addAction(QLatin1String("edit_duplicate_operation"), m_duplicateAction);
     m_duplicateAction->setShortcut(Qt::CTRL + Qt::Key_D);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_duplicate_operation", m_duplicateAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_duplicate_operation", m_duplicateAction);
 
     //------------
     m_createTemplateAction = new KAction(KIcon("skrooge_template"), i18nc("Verb", "Create template"), this);
@@ -99,7 +103,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     actionCollection()->addAction(QLatin1String("edit_template_operation"), m_createTemplateAction);
     m_createTemplateAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_T);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_template_operation", m_createTemplateAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_template_operation", m_createTemplateAction);
 
     //------------
     m_switchToPointedAction = new KAction(KIcon("dialog-ok"), i18nc("Verb, mark an object", "Point"), this);
@@ -107,7 +111,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     actionCollection()->addAction(QLatin1String("edit_point_selected_operation"), m_switchToPointedAction);
     m_switchToPointedAction->setShortcut(Qt::CTRL + Qt::Key_R);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_point_selected_operation", m_switchToPointedAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_point_selected_operation", m_switchToPointedAction);
 
     //------------
     KAction* fastEditionAction = new KAction(KIcon("games-solve"), i18nc("Verb", "Fast edit"), this);
@@ -115,17 +119,23 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     fastEditionAction->setEnabled(false);
     fastEditionAction->setShortcut(Qt::Key_F10);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("fast_edition", fastEditionAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("fast_edition", fastEditionAction);
 
     //------------
     QStringList overlayopen;
     overlayopen.push_back("skg_open");
+    m_open = new KAction(KIcon(icon(), NULL, overlayopen), i18nc("Verb", "Open operations..."), this);
+    connect(m_open, SIGNAL(triggered(bool)), this, SLOT(actionOpenOperations()));
+    actionCollection()->addAction(QLatin1String("open"), m_open);
+
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("open", m_open);
+
     m_openHighLights = new KAction(KIcon("rating", NULL, overlayopen), i18nc("Verb", "Open highlights..."), this);
     connect(m_openHighLights, SIGNAL(triggered(bool)), this, SLOT(actionOpenHighLights()));
     actionCollection()->addAction(QLatin1String("view_open_highlight"), m_openHighLights);
     m_openHighLights->setShortcut(Qt::META + Qt::Key_H);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("view_open_highlight", m_openHighLights);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("view_open_highlight", m_openHighLights);
 
     //------------
     m_openLastModified = new KAction(KIcon("view-refresh", NULL, overlayopen), i18nc("Verb", "Open last modified..."), this);
@@ -133,7 +143,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     actionCollection()->addAction(QLatin1String("view_open_last_modified"), m_openLastModified);
     m_openLastModified->setShortcut(Qt::META + Qt::Key_L);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("view_open_last_modified", m_openLastModified);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("view_open_last_modified", m_openLastModified);
 
     //------------
     m_openSuboperations = new KAction(KIcon("split", NULL, overlayopen), i18nc("Verb", "Open sub operations..."), this);
@@ -141,7 +151,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     actionCollection()->addAction(QLatin1String("view_open_suboperations"), m_openSuboperations);
     m_openSuboperations->setShortcut(Qt::META + Qt::Key_S);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("view_open_suboperations", m_openSuboperations);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("view_open_suboperations", m_openSuboperations);
 
     //------------
     m_openDuplicate = new KAction(KIcon("skrooge_duplicate", NULL, overlayopen), i18nc("Verb", "Open potential duplicates..."), this);
@@ -149,7 +159,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     actionCollection()->addAction(QLatin1String("view_open_duplicates"), m_openDuplicate);
     m_openDuplicate->setShortcut(Qt::META + Qt::Key_D);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("view_open_duplicates", m_openDuplicate);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("view_open_duplicates", m_openDuplicate);
 
     //------------
     m_groupOperation = new KAction(KIcon("view-financial-transfer"), i18nc("Verb", "Group operations"), this);
@@ -157,7 +167,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     actionCollection()->addAction(QLatin1String("edit_group_operation"), m_groupOperation);
     m_groupOperation->setShortcut(Qt::CTRL + Qt::Key_G);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_group_operation", m_groupOperation);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_group_operation", m_groupOperation);
 
     //------------
     QStringList overlay;
@@ -167,7 +177,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     actionCollection()->addAction(QLatin1String("edit_ungroup_operation"), m_ungroupOperation);
     m_ungroupOperation->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_G);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_ungroup_operation", m_ungroupOperation);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_ungroup_operation", m_ungroupOperation);
 
     //------------
     m_mergeOperationAction = new KAction(KIcon("split"), i18nc("Verb, action to merge", "Merge sub operations"), this);
@@ -175,7 +185,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     actionCollection()->addAction(QLatin1String("merge_sub_operations"), m_mergeOperationAction);
     m_mergeOperationAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_M);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("merge_sub_operations", m_mergeOperationAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("merge_sub_operations", m_mergeOperationAction);
     return true;
 }
 
@@ -190,7 +200,9 @@ void SKGOperationPlugin::refresh()
         if (m_openLastModified) m_openLastModified->setEnabled(test && m_currentBankDocument->getNbTransaction() > 0);
 
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
-        if (selection.count() > 0) {
+        int nb = selection.count();
+        if (m_open) m_open->setEnabled(nb > 0);
+        if (nb > 0) {
             bool onOperation = (selection.at(0).getRealTable() == "operation" &&  selection.at(0).getTable() != "v_operation_consolidated");
             if (m_duplicateAction) m_duplicateAction->setEnabled(onOperation);
             if (m_createTemplateAction) m_createTemplateAction->setEnabled(onOperation);
@@ -450,6 +462,228 @@ void SKGOperationPlugin::actionOpenHighLights()
     openHighLights();
 }
 
+void SKGOperationPlugin::actionOpenOperations()
+{
+    SKGTRACEIN(10, "SKGBankPluginWidget::onDoubleClickedAccount");
+    if (SKGMainPanel::getMainPanel()) {
+        SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
+
+        int nb = selection.count();
+        if (nb > 0) {
+            QString wc;
+            QString title;
+            QString icon;
+            QString table = selection.at(0).getRealTable();
+            QString view;
+            QString account;
+            if (table == "account") {
+                if (nb == 1) {
+                    SKGAccountObject tmp = selection.at(0);
+                    account = tmp.getName();
+                } else {
+                    //Build whereclause and title
+                    wc = "rd_account_id in (";
+                    title = i18nc("Noun, a list of items", "Operations of account:");
+
+                    for (int i = 0; i < nb; ++i) {
+                        SKGAccountObject tmp = selection.at(i);
+                        if (i) {
+                            wc += ',';
+                            title += ',';
+                        }
+                        wc += SKGServices::intToString(tmp.getID());
+                        title += i18n("'%1'", tmp.getDisplayName());
+                    }
+                    wc += ')';
+                    //Set icon
+                    icon = "view-bank-account";
+                }
+            } else if (table == "unit") {
+                //Build whereclause and title
+                wc = "rc_unit_id in (";
+                title = i18nc("Noun, a list of items", "Operations with unit:");
+
+                for (int i = 0; i < nb; ++i) {
+                    SKGUnitObject tmp = selection.at(i);
+                    if (i) {
+                        wc += ',';
+                        title += ',';
+                    }
+                    wc += SKGServices::intToString(tmp.getID());
+                    title += i18n("'%1'", tmp.getDisplayName());
+                }
+                wc += ')';
+
+                //Set icon
+                icon = "view-currency-list";
+            } else if (table == "category") {
+                title = i18nc("Noun, a list of items", "Sub operations with category:");
+
+                for (int i = 0; i < nb; ++i) {
+                    SKGCategoryObject tmp = selection.at(i);
+                    if (i) {
+                        wc += " OR ";
+                        title += ',';
+                    }
+
+                    QString name = tmp.getFullName();
+
+                    wc += "(t_REALCATEGORY";
+                    if (name.isEmpty()) wc += " IS NULL OR t_REALCATEGORY='')";
+                    else wc += " = '" % SKGServices::stringToSqlString(name) % "' OR t_REALCATEGORY like '" % SKGServices::stringToSqlString(name) % OBJECTSEPARATOR % "%')";
+
+                    title += i18n("'%1'", tmp.getDisplayName());
+                }
+
+                //Set icon
+                icon = "skrooge_category";
+                view = "v_operation_consolidated";
+            } else if (table == "refund") {
+                //Build whereclause and title
+                wc = "t_REALREFUND in (";
+                title = i18nc("Noun, a list of items", "Sub operations followed by tracker:");
+
+                for (int i = 0; i < nb; ++i) {
+                    SKGTrackerObject tmp = selection.at(i);
+                    if (i) {
+                        wc += ',';
+                        title += ',';
+                    }
+                    wc += '\'' % SKGServices::stringToSqlString(tmp.getName()) % '\'';
+                    title += i18n("'%1'", tmp.getDisplayName());
+                }
+                wc += ')';
+
+                //Set icon
+                icon = "skrooge_tracker";
+                view = "v_operation_consolidated";
+            } else if (table == "payee") {
+                //Build whereclause and title
+                wc = "r_payee_id in (";
+                title = i18nc("Noun, a list of items", "Operations assigned to payee:");
+
+                for (int i = 0; i < nb; ++i) {
+                    SKGPayeeObject tmp = selection.at(i);
+                    if (i) {
+                        wc += ',';
+                        title += ',';
+                    }
+                    wc += SKGServices::intToString(tmp.getID());
+                    title += i18n("'%1'", tmp.getDisplayName());
+                }
+                wc += ')';
+
+                //Set icon
+                icon = "skrooge_payee";
+            } else if (table == "budget") {
+                title = i18nc("Noun, a list of items", "Operations assigned to budget:");
+
+                for (int i = 0; i < nb; ++i) {
+                    SKGBudgetObject tmp = selection.at(i);
+                    if (i) {
+                        wc += " OR ";
+                        title += ',';
+                    }
+
+                    QString y = SKGServices::intToString(tmp.getYear());
+                    QString m = SKGServices::intToString(tmp.getMonth());
+                    if (m.length() == 1) m = '0' % m;
+
+                    wc += "(i_IDCATEGORY IN (SELECT bc.id_category FROM budgetcategory bc WHERE bc.id=" % SKGServices::intToString(tmp.getID()) % ") AND "
+                          "STRFTIME('%Y', d_date)='" % y % '\'';
+                    if (m != "00") wc += " AND STRFTIME('%m', d_date)='" % m % '\'';
+                    wc += ')';
+                    title += i18n("'%1'", tmp.getDisplayName());
+                }
+
+                //Set icon
+                icon = "view-income-categories";
+                view = "v_operation_consolidated";
+            } else if (table == "recurrentoperation") {
+                title = i18nc("Noun, a list of items", "Scheduled operations:");
+
+                for (int i = 0; i < nb; ++i) {
+                    SKGRecurrentOperationObject tmp = selection.at(i);
+                    if (i) {
+                        wc += " OR ";
+                        title += ',';
+                    }
+
+                    wc += "(EXISTS(SELECT 1 FROM recurrentoperation s WHERE s.rd_operation_id=v_operation_display_all.id and s.id=" % SKGServices::intToString(tmp.getID()) % ") OR r_recurrentoperation_id=" % SKGServices::intToString(tmp.getID()) + ')';
+                    title += i18n("'%1'", tmp.getDisplayName());
+                }
+
+                //Set icon
+                icon = "chronometer";
+            } else if (table == "rule") {
+                title = i18nc("Noun, a list of items", "Sub operations corresponding to rule:");
+
+                for (int i = 0; i < nb; ++i) {
+                    SKGRuleObject tmp = selection.at(i);
+                    if (i) {
+                        wc += " OR ";
+                        title += ',';
+                    }
+
+                    wc += "i_SUBOPID in (SELECT i_SUBOPID FROM v_operation_prop WHERE " % tmp.getSelectSqlOrder() % ')';
+                    title += i18n("'%1'", tmp.getDisplayName());
+                }
+
+                //Set icon
+                icon = "edit-find";
+                view = "v_operation_consolidated";
+            } else if (table == "operation") {
+                //Build whereclause and title
+                if (selection.at(0).getTable() != "v_operation_consolidated") {
+                    title = i18nc("Noun, a list of items", "Sub operations grouped or split of:");
+                    view = "v_operation_consolidated";
+                } else {
+                    title = i18nc("Noun, a list of items", "Operations grouped with:");
+                    view = "v_operation_display_all";
+                }
+
+                for (int i = 0; i < nb; ++i) {
+                    SKGOperationObject tmp = selection.at(i);
+                    if (i) {
+                        wc += ',';
+                        title += ',';
+                    }
+
+                    int opid = tmp.getID();
+                    wc += "(id=" % SKGServices::intToString(opid);
+
+                    opid = SKGServices::stringToInt(tmp.getAttribute("i_group_id"));
+                    if (opid != 0) wc += " or i_group_id=" % SKGServices::intToString(opid);
+                    wc += ')';
+
+                    title += i18n("'%1'", tmp.getDisplayName());
+                }
+
+                //Set icon
+                icon = "view-financial-list";
+            }
+
+            //Call operation plugin
+            QDomDocument doc("SKGML");
+            doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter(view != "v_operation_consolidated" ? "SKGOPERATION_DEFAULT_PARAMETERS" : "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS"));
+            QDomElement root = doc.documentElement();
+            if (root.isNull()) {
+                root = doc.createElement("parameters");
+                doc.appendChild(root);
+            }
+
+            if (!view.isEmpty()) root.setAttribute("operationTable", view);
+            if (!wc.isEmpty()) root.setAttribute("operationWhereClause", wc);
+            if (!title.isEmpty()) root.setAttribute("title", title);
+            if (!icon.isEmpty()) root.setAttribute("title_icon", icon);
+            if (!account.isEmpty()) root.setAttribute("account", account);
+            else root.setAttribute("currentPage", "-1");
+
+            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
+        }
+    }
+}
+
 void SKGOperationPlugin::openHighLights()
 {
     SKGTRACEIN(10, "SKGOperationPlugin::openHighLights");
@@ -466,8 +700,6 @@ void SKGOperationPlugin::openHighLights()
         doc.appendChild(root);
     }
 
-    root.setAttribute("account", i18nc("For all accounts", "All"));
-    root.setAttribute("operationTable", "v_operation_display");
     root.setAttribute("operationWhereClause", wc);
     root.setAttribute("title", title);
     root.setAttribute("title_icon", "rating");
@@ -490,8 +722,6 @@ void SKGOperationPlugin::actionOpenDuplicate()
         doc.appendChild(root);
     }
 
-    root.setAttribute("account", i18nc("For all accounts", "All"));
-    root.setAttribute("operationTable", "v_operation_display");
     root.setAttribute("operationWhereClause", wc);
     root.setAttribute("title", title);
     root.setAttribute("title_icon", "skrooge_duplicate");
@@ -514,8 +744,6 @@ void SKGOperationPlugin::actionOpenLastModified()
         doc.appendChild(root);
     }
 
-    root.setAttribute("account", i18nc("For all accounts", "All"));
-    root.setAttribute("operationTable", "v_operation_display");
     root.setAttribute("operationWhereClause", wc);
     root.setAttribute("title", title);
     root.setAttribute("title_icon", "view-refresh");
@@ -535,7 +763,6 @@ void SKGOperationPlugin::actionOpenSubOperations()
         doc.appendChild(root);
     }
 
-    root.setAttribute("account", i18nc("For all accounts", "All"));
     root.setAttribute("operationTable", "v_operation_consolidated");
     root.setAttribute("operationWhereClause", "");
     root.setAttribute("title", i18nc("Noun, a list of items", "Sub operations"));
@@ -619,7 +846,7 @@ SKGAdviceList SKGOperationPlugin::advices() const
     }
 
     //Check operations in group of only one transaction
-    m_currentBankDocument->existObjects("v_operation_display", "i_group_id<>0 AND (SELECT COUNT(1) FROM operation o WHERE o.i_group_id=operation.i_group_id)<2", exist);
+    m_currentBankDocument->existObjects("v_operation_display", "i_group_id<>0 AND (SELECT COUNT(1) FROM operation o WHERE o.i_group_id=v_operation_display.i_group_id)<2", exist);
     if (exist) {
         SKGAdvice ad;
         ad.setUUID("skgoperationplugin_groupofone");
@@ -677,7 +904,6 @@ SKGError SKGOperationPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             doc.appendChild(root);
         }
 
-        root.setAttribute("operationTable", "v_operation_display");
         root.setAttribute("operationWhereClause", "i_number=" % SKGServices::stringToSqlString(num) % " AND t_ACCOUNT='" % SKGServices::stringToSqlString(account) % '\'');
         root.setAttribute("title", i18nc("Noun, a list of items", "Operations of '%1' with duplicate number %2", account, num));
         root.setAttribute("title_icon", "security-low");
@@ -714,7 +940,6 @@ SKGError SKGOperationPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             doc.appendChild(root);
         }
 
-        root.setAttribute("operationTable", "v_operation_display");
         root.setAttribute("operationWhereClause", "EXISTS (SELECT 1 FROM suboperation WHERE rd_operation_id=v_operation_display.id AND r_category_id=0)");
         root.setAttribute("title", i18nc("Noun, a list of items", "Operations without category"));
         root.setAttribute("title_icon", "skrooge_category");
@@ -731,7 +956,6 @@ SKGError SKGOperationPlugin::executeAdviceCorrection(const QString& iAdviceIdent
                 doc.appendChild(root);
             }
 
-            root.setAttribute("operationTable", "v_operation_display");
             root.setAttribute("operationWhereClause", "v_operation_display.i_group_id<>0 AND (SELECT COUNT(1) FROM operation o WHERE o.i_group_id=v_operation_display.i_group_id)<2");
             root.setAttribute("title", i18nc("Noun, a list of items", "Operations in groups with only one operation"));
             root.setAttribute("title_icon", "view-financial-transfer");
@@ -764,7 +988,6 @@ SKGError SKGOperationPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             doc.appendChild(root);
         }
 
-        root.setAttribute("operationTable", "v_operation_display");
         root.setAttribute("operationWhereClause", "r_payee_id=0");
         root.setAttribute("title", i18nc("Noun, a list of items", "Operations without payee"));
         root.setAttribute("title_icon", "skrooge_payee");
