@@ -66,7 +66,7 @@ bool SKGPayeePlugin::setupActions(SKGDocument* iDocument, const QStringList& iAr
     connect(deleteUnusedPayeesAction, SIGNAL(triggered(bool)), SLOT(deleteUnusedPayees()));
     actionCollection()->addAction(QLatin1String("edit_delete_unused_payees"), deleteUnusedPayeesAction);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_delete_unused_payees", deleteUnusedPayeesAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_delete_unused_payees", deleteUnusedPayeesAction);
 
     return true;
 }
