@@ -59,16 +59,18 @@ SKGPayeePluginWidget::SKGPayeePluginWidget(SKGDocument* iDocument)
 
     //Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
+        ui.kView->getView()->insertGlobalAction();
+        ui.kView->getView()->insertGlobalAction("open");
+        ui.kView->getView()->insertGlobalAction("open_report");
+        ui.kView->getView()->insertGlobalAction("edit_find");
+        ui.kView->getView()->insertGlobalAction();
         ui.kView->getView()->insertGlobalAction("edit_delete");
         ui.kView->getView()->insertGlobalAction();
         ui.kView->getView()->insertGlobalAction("edit_switch_highlight");
-        ui.kView->getView()->insertGlobalAction();
-        ui.kView->getView()->insertGlobalAction("edit_find");
-        ui.kView->getView()->insertGlobalAction("open_report");
     }
     connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     connect(ui.kView->getView(), SIGNAL(clickEmptyArea()), this, SLOT(cleanEditor()));
-    connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onDoubleClick()));
+    connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
     //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
@@ -236,50 +238,6 @@ void SKGPayeePluginWidget::onModifyPayee()
     SKGMainPanel::displayErrorMessage(err);
 }
 
-void SKGPayeePluginWidget::onDoubleClick()
-{
-    _SKGTRACEIN(10, "SKGPayeePluginWidget::onDoubleClick");
-
-    //Get selection
-    SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
-    if (selection.count() == 1) {
-        SKGPayeeObject payee(selection.at(0));
-        QString name = payee.getName();
-
-        //Build where clause and title
-        QString wc = "t_PAYEE = '" % SKGServices::stringToSqlString(name) % '\'';
-        QString title = i18nc("Noun, a list of items", "Operations assigned to payee '%1'",  name);
-
-        //Open
-        if (QApplication::keyboardModifiers() &Qt::ControlModifier && QApplication::keyboardModifiers() &Qt::ShiftModifier) {
-            //Call debug plugin
-            QDomDocument doc("SKGML");
-            QDomElement root = doc.createElement("parameters");
-            doc.appendChild(root);
-            root.setAttribute("sqlOrder", "SELECT * from v_operation_display WHERE " % wc);
-
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Debug plugin"), -1, doc.toString());
-        } else {
-            //Call operation plugin
-            QDomDocument doc("SKGML");
-            doc.setContent(getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
-            QDomElement root = doc.documentElement();
-            if (root.isNull()) {
-                root = doc.createElement("parameters");
-                doc.appendChild(root);
-            }
-
-            root.setAttribute("operationTable", "v_operation_display");
-            root.setAttribute("operationWhereClause", wc);
-            root.setAttribute("title", title);
-            root.setAttribute("title_icon", "skrooge_payee");
-            root.setAttribute("currentPage", "-1");
-
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
-        }
-    }
-}
-
 void SKGPayeePluginWidget::cleanEditor()
 {
     if (getNbSelectedObjects() == 0) {
