@@ -70,7 +70,10 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     // FIXME: Icons are not related to the text...
     ui.kMode->addItem(KIcon("office-chart-pie"), i18nc("Display graph values as the sum of operations amount", "Sum of operations"), 0);
     ui.kMode->addItem(KIcon("office-chart-line"), i18nc("Display graph values as the cumulated sum of operations amount", "Cumulated sum of operations"), 1);
-    ui.kMode->addItem(KIcon("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Percentage"), 2);
+    ui.kMode->addItem(KIcon("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Percent of columns"), 2);
+    ui.kMode->addItem(KIcon("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Absolute percent of columns"), 5);
+    ui.kMode->addItem(KIcon("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Percent of lines"), 4);
+    ui.kMode->addItem(KIcon("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Absolute percent of lines"), 6);
     ui.kMode->addItem(KIcon("milestone"), i18nc("Display graph values as a number of operations (or transaction)", "Count number of operations"), 3);
 
     ui.kForecastCmb->addItem(i18nc("Noun", "None"), 0);
@@ -121,7 +124,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
 
     //Adding properties
     QStringList properties;
-    iDocument->getDistinctValues("parameters", "t_name", "t_uuid_parent like '%-operation'", properties);
+    iDocument->getDistinctValues("parameters", "t_name", "t_uuid_parent like '%-operation' AND t_name NOT LIKE 'SKG_%'", properties);
     int nb = properties.count();
     for (int i = 0; i < nb; ++i)
         m_attsForLines.push_back("p_" % properties.at(i));
@@ -1228,13 +1231,13 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     }
 
                     //Mode percent
-                    bool modePercent = (mode == 2);
+                    bool modePercent = (mode == 2 || mode == 4 || mode == 5 || mode == 6);
                     if (modePercent) {
                         primaryUnit.Symbol = '%';
                         SKGServices::SKGUnitInfo empty;
                         secondaryUnit = empty;
 
-                        table = SKGServices::getPercentTable(table);
+                        table = SKGServices::getPercentTable(table, (mode == 2 || mode == 5), (mode == 5 || mode == 6));
                     }
 
                     //Mode Count
