@@ -71,7 +71,7 @@ bool SKGScheduledPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     actionCollection()->addAction(QLatin1String("schedule_operation"), m_scheduleOperationAction);
     m_scheduleOperationAction->setShortcut(Qt::CTRL + Qt::Key_I);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("schedule_operation", m_scheduleOperationAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("schedule_operation", m_scheduleOperationAction);
     return true;
 }
 
@@ -267,12 +267,25 @@ void SKGScheduledPlugin::actionScheduleOperation()
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
         if (nb && m_currentBankDocument) {
+            QStringList list;
             SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Operation schedule"), err, nb);
             for (int i = 0; !err && i < nb; ++i) {
                 SKGOperationObject operationObj = selection.at(i);
                 SKGRecurrentOperationObject rop;
                 err = scheduleOperation(operationObj, rop);
                 if (!err) err = m_currentBankDocument->stepForward(i + 1);
+                list.push_back(operationObj.getUniqueID());
+            }
+
+            if (!err) {
+                //Call operation plugin
+                QDomDocument doc("SKGML");
+                QDomElement root = doc.createElement("parameters");
+                doc.appendChild(root);
+
+                root.setAttribute("selection", SKGServices::stringsToCsv(list));
+
+                SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge scheduled plugin"), -1, doc.toString());
             }
         }
 
@@ -317,7 +330,7 @@ SKGAdviceList SKGScheduledPlugin::advices() const
     }
 
     //Possible recurrent operations
-    m_currentBankDocument->executeSelectSqliteOrder("SELECT op1.id, op1.t_displayname FROM v_operation_displayname op1 WHERE op1.d_date>date('now','-2 month') AND op1.t_TRANSFER='N' AND op1.r_recurrentoperation_id=0 AND "
+    m_currentBankDocument->executeSelectSqliteOrder("SELECT op1.id, op1.t_displayname FROM v_operation_displayname op1 WHERE op1.d_date>date('now','-2 month') AND op1.t_TRANSFER='N' AND op1.r_recurrentoperation_id=0 AND op1.d_date<>'0000-00-00' AND "
             "EXISTS (SELECT 1 FROM v_operation op2 WHERE op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.f_CURRENTAMOUNT=op2.f_CURRENTAMOUNT AND op1.d_date=date(op2.d_date, '+1 month')) AND "
             "NOT EXISTS (SELECT 1 FROM recurrentoperation ro, v_operation op2 WHERE ro.rd_operation_id=op2.id AND ro.i_period_increment=1 AND ro.t_period_unit='M' AND op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.f_CURRENTAMOUNT=op2.f_CURRENTAMOUNT)", result);
     nb = result.count();
