@@ -42,20 +42,28 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
 
     ui.setupUi(this);
 
+    //Set show widget
+    ui.kView->getShowWidget()->addItem("ongoing", i18n("Ongoing"), "", "t_times='N' OR i_nb_times>0", "", "", "finished", "");
+    ui.kView->getShowWidget()->addItem("finished", i18n("Finished"), "dialog-close", "t_times='Y' AND i_nb_times=0", "", "", "ongoing", "");
+    ui.kView->getShowWidget()->setDefaultState("ongoing;finished");
+
     ui.kView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_recurrentoperation_display", "", this, "", false));
 
-    connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onDoubleClick()));
+    connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
     //Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
-        ui.kView->getView()->insertGlobalAction("edit_delete");
         ui.kView->getView()->insertGlobalAction();
+        ui.kView->getView()->insertGlobalAction("open");
 
         m_jumpAction = new KAction(KIcon("skg_open"), ui.kJumpBtn->text(), this);
         connect(m_jumpAction, SIGNAL(triggered(bool)), this, SLOT(onJumpToTheOperation()));
 
         ui.kView->getView()->insertAction(0, m_jumpAction);
+        ui.kView->getView()->insertGlobalAction();
+        ui.kView->getView()->insertGlobalAction("edit_delete");
+        ui.kView->getView()->insertGlobalAction();
     }
 
     //Add Standard KDE Icons to buttons to Operations
@@ -64,6 +72,9 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
     ui.kJumpBtn->setIcon(KIcon("skg_open"));
 
     ui.kTitle->setPixmap(KIcon("dialog-information").pixmap(22, 22), KTitleWidget::ImageLeft);
+    bool exist = false;
+    getDocument()->existObjects("recurrentoperation", "", exist);
+    ui.kTitle->setVisible(!exist);
 
     //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter(this);
@@ -105,6 +116,14 @@ void SKGScheduledPluginWidget::setState(const QString& iState)
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
     ui.kView->setState(root.attribute("view"));
+
+    QString selection = root.attribute("selection");
+
+    if (!selection.isEmpty()) {
+        QStringList uuids = SKGServices::splitCSVLine(selection);
+        ui.kView->getView()->selectObjects(uuids, true);  //FIXME //TODO
+        onSelectionChanged();
+    }
 }
 
 QString SKGScheduledPluginWidget::getDefaultStateAttribute()
@@ -117,49 +136,6 @@ QWidget* SKGScheduledPluginWidget::mainWidget() const
     return ui.kView->getView();
 }
 
-void SKGScheduledPluginWidget::onDoubleClick()
-{
-    _SKGTRACEIN(10, "SKGScheduledPluginWidget::onDoubleClick");
-
-    //Get selection
-    SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
-    if (selection.count() == 1) {
-        SKGRecurrentOperationObject recOp(selection.at(0));
-
-        //Build where clause and title
-        QString wc = "EXISTS(SELECT 1 FROM recurrentoperation s WHERE s.rd_operation_id=v_operation_display.id and s.id=" % SKGServices::intToString(recOp.getID()) % ") OR r_recurrentoperation_id=" % SKGServices::intToString(recOp.getID());
-        QString title = i18nc("Noun, a list of items", "Recurrent operations");
-
-        //Open
-        if (QApplication::keyboardModifiers() &Qt::ControlModifier && QApplication::keyboardModifiers() &Qt::ShiftModifier) {
-            //Call debug plugin
-            QDomDocument doc("SKGML");
-            QDomElement root = doc.createElement("parameters");
-            doc.appendChild(root);
-            root.setAttribute("sqlOrder", "SELECT * from v_operation_display WHERE " % wc);
-
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Debug plugin"), -1, doc.toString());
-        } else {
-            //Call operation plugin
-            QDomDocument doc("SKGML");
-            doc.setContent(getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
-            QDomElement root = doc.documentElement();
-            if (root.isNull()) {
-                root = doc.createElement("parameters");
-                doc.appendChild(root);
-            }
-
-            root.setAttribute("operationTable", "v_operation_display");
-            root.setAttribute("operationWhereClause", wc);
-            root.setAttribute("title", title);
-            root.setAttribute("title_icon", "chronometer");
-            root.setAttribute("currentPage", "-1");
-
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
-        }
-    }
-}
-
 void SKGScheduledPluginWidget::onJumpToTheOperation()
 {
     //Get selection
@@ -193,9 +169,7 @@ void SKGScheduledPluginWidget::onJumpToTheOperation()
                 doc.appendChild(root);
             }
 
-            root.setAttribute("operationTable", "v_operation_display");
             root.setAttribute("operationWhereClause", wc);
-            root.setAttribute("modeTemplate", op.isTemplate() ?  "Y" : "N");
             root.setAttribute("currentPage", "1");
             root.setAttribute("selection", op.getUniqueID());
             root.setAttribute("title", title);
