@@ -105,12 +105,14 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
 
     //Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
+        ui.kView->getView()->insertGlobalAction();
+        ui.kView->getView()->insertGlobalAction("open");
+        ui.kView->getView()->insertGlobalAction("open_report");
+        ui.kView->getView()->insertGlobalAction();
         ui.kView->getView()->insertGlobalAction("edit_delete");
         ui.kView->getView()->insertGlobalAction();
         ui.kView->getView()->insertGlobalAction("edit_switch_highlight");
         ui.kView->getView()->insertGlobalAction();
-        ui.kView->getView()->insertGlobalAction("open_report");
-        ui.kView->getView()->insertGlobalAction();
         ui.kView->getView()->insertGlobalAction("execute_all");
         ui.kView->getView()->insertGlobalAction("execute_imported");
         ui.kView->getView()->insertGlobalAction("execute_not_validated");
@@ -129,7 +131,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     ui.kWidgetSelector->setSelectedMode(0);
 
     connect(ui.kView->getView(), SIGNAL(clickEmptyArea()), this, SLOT(cleanEditor()));
-    connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onDoubleClick()));
+    connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
     //Refresh
@@ -521,18 +523,6 @@ void SKGSearchPluginWidget::open(const SKGRuleObject& iRule)
     }
 }
 
-void SKGSearchPluginWidget::onDoubleClick()
-{
-    _SKGTRACEIN(10, "SKGSearchPluginWidget::onDoubleClick");
-
-    //Get selection
-    SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
-    if (selection.count() == 1) {
-        SKGRuleObject rule(selection.at(0));
-        SKGSearchPluginWidget::open(rule);
-    }
-}
-
 void SKGSearchPluginWidget::onEditorModified()
 {
     SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
