@@ -37,6 +37,24 @@ SKGUnitBoardWidget::SKGUnitBoardWidget(SKGDocument* iDocument)
     //Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
+    m_menuFavorite = new KAction(KIcon("rating"), i18nc("Display only favorite accounts", "Highlighted only"), this);
+    m_menuFavorite->setCheckable(true);
+    m_menuFavorite->setChecked(false);
+    connect(m_menuFavorite, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
+    addAction(m_menuFavorite);
+
+    {
+        QAction* sep = new QAction(this);
+        sep->setSeparator(true);
+        addAction(sep);
+    }
+
+    m_menuCurrencies = new KAction(i18nc("Noun, a country's currency", "Currencies"), this);
+    m_menuCurrencies->setCheckable(true);
+    m_menuCurrencies->setChecked(true);
+    connect(m_menuCurrencies, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
+    addAction(m_menuCurrencies);
+
     m_menuIndexes = new KAction(i18nc("Financial indexes, used as an indicator of financial places' health. Examples : Dow Jones, CAC40, Nikkei...", "Indexes"), this);
     m_menuIndexes->setCheckable(true);
     m_menuIndexes->setChecked(true);
@@ -49,6 +67,12 @@ SKGUnitBoardWidget::SKGUnitBoardWidget(SKGDocument* iDocument)
     connect(m_menuShares, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
     addAction(m_menuShares);
 
+    m_menuObjects = new KAction(i18nc("Noun, a physical object like a house or a car", "Objects"), this);
+    m_menuObjects->setCheckable(true);
+    m_menuObjects->setChecked(true);
+    connect(m_menuObjects, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
+    addAction(m_menuObjects);
+
     m_menuSharesOwnedOnly = new KAction(i18nc("Only show the list of Shares (financial shares) that you own", "Shares owned only"), this);
     m_menuSharesOwnedOnly->setCheckable(true);
     m_menuSharesOwnedOnly->setChecked(false);
@@ -65,6 +89,9 @@ SKGUnitBoardWidget::~SKGUnitBoardWidget()
     m_menuIndexes = NULL;
     m_menuShares = NULL;
     m_menuSharesOwnedOnly = NULL;
+    m_menuObjects = NULL;
+    m_menuCurrencies = NULL;
+    m_menuFavorite = NULL;
 }
 
 QString SKGUnitBoardWidget::getState()
@@ -73,9 +100,12 @@ QString SKGUnitBoardWidget::getState()
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
 
+    root.setAttribute("m_menuCurrencies", m_menuCurrencies && m_menuCurrencies->isChecked() ? "Y" : "N");
+    root.setAttribute("m_menuObjects", m_menuObjects && m_menuObjects->isChecked() ? "Y" : "N");
     root.setAttribute("menuIndexes", m_menuIndexes && m_menuIndexes->isChecked() ? "Y" : "N");
     root.setAttribute("menuShares", m_menuShares && m_menuShares->isChecked() ? "Y" : "N");
     root.setAttribute("menuSharesOwnedOnly", m_menuSharesOwnedOnly && m_menuSharesOwnedOnly->isChecked() ? "Y" : "N");
+    root.setAttribute("menuFavorite", m_menuFavorite && m_menuFavorite->isChecked() ? "Y" : "N");
     return doc.toString();
 }
 
@@ -85,9 +115,12 @@ void SKGUnitBoardWidget::setState(const QString& iState)
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
+    if (m_menuCurrencies) m_menuCurrencies->setChecked(root.attribute("m_menuCurrencies") == "Y");
+    if (m_menuObjects) m_menuObjects->setChecked(root.attribute("m_menuObjects") == "Y");
     if (m_menuIndexes) m_menuIndexes->setChecked(root.attribute("menuIndexes") != "N");
     if (m_menuShares) m_menuShares->setChecked(root.attribute("menuShares") != "N");
     if (m_menuSharesOwnedOnly) m_menuSharesOwnedOnly->setChecked(root.attribute("menuSharesOwnedOnly") != "N");
+    if (m_menuFavorite) m_menuFavorite->setChecked(root.attribute("menuFavorite") == "Y");
 
     dataModified("", 0);
 }
@@ -118,9 +151,20 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
                     if (m_menuSharesOwnedOnly->isChecked()) wc += "(t_type='S' AND f_QUANTITYOWNED>0)";
                     else wc += "t_type='S'";
                 }
+                if (m_menuCurrencies->isChecked()) {
+                    if (!wc.isEmpty()) wc += " OR ";
+                    wc += "t_type IN ('1','2','C')";
+                }
+                if (m_menuObjects->isChecked()) {
+                    if (!wc.isEmpty()) wc += " OR ";
+                    wc += "t_type='O'";
+                }
             }
 
             if (wc.isEmpty()) wc = "1=0";
+            else if (m_menuFavorite && m_menuFavorite->isChecked()) {
+                wc = "t_bookmarked='Y' AND (" % wc % ')';
+            }
 
             SKGObjectBase::SKGListSKGObjectBase objs;
             SKGError err = getDocument()->getObjects("v_unit_display", wc % " ORDER BY t_type DESC, t_name ASC", objs);
@@ -184,7 +228,6 @@ void SKGUnitBoardWidget::onOpen(const QString& iLink)
             doc.appendChild(root);
         }
 
-        root.setAttribute("operationTable", "v_operation_display");
         root.setAttribute("operationWhereClause", wc);
         root.setAttribute("title", title);
         root.setAttribute("title_icon", "view-currency-list");
