@@ -64,36 +64,39 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
 
     ui.kUnitTableViewEdition->getShowWidget()->addItem("all", i18nc("Noun, items to display", "All"), "",
             "",
-            "currency;share;index;object");
+            "currency;share;index;object",//Check when checked
+            "highlighted");//Uncheck when checked
+    ui.kUnitTableViewEdition->getShowWidget()->addItem("highlighted", i18n("Highlighted only"), "rating", "t_bookmarked='Y'", "", "all;currency;share;index;object", "all");
     ui.kUnitTableViewEdition->getShowWidget()->addSeparator();
     ui.kUnitTableViewEdition->getShowWidget()->addItem("currency", i18nc("Noun, a country's currency", "Currency"), "",
             "t_type IN ('1','2','C')",
             "",  //Check when checked
-            "",       //Uncheck when checked
+            "highlighted",       //Uncheck when checked
             "",       //Check when unchecked
             "all"     //Uncheck when unchecked
                                                       );
     ui.kUnitTableViewEdition->getShowWidget()->addItem("share", i18nc("Noun, a financial share, as in a stock market", "Share"), "",
             "t_type='S'",
             "",
-            "",
+            "highlighted",
             "",
             "all"
                                                       );
     ui.kUnitTableViewEdition->getShowWidget()->addItem("index", i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40...", "Index"), "",
             "t_type='I'",
             "",
-            "",
+            "highlighted",
             "",
             "all;current"
                                                       );
     ui.kUnitTableViewEdition->getShowWidget()->addItem("object", i18nc("Noun, a physical object like a house or a car", "Object"), "",
             "t_type='O'",
             "",
-            "",
+            "highlighted",
             "",
             "all"
                                                       );
+
     ui.kUnitTableViewEdition->getShowWidget()->setDefaultState("all;currency;share;index;object");
 
     ui.kGraph->getShowWidget()->setState("\"graph\"");
@@ -192,15 +195,18 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
 
         //Add registered global action in contextual menu
         if (SKGMainPanel::getMainPanel()) {
+            ui.kUnitTableViewEdition->getView()->insertGlobalAction();
+            ui.kUnitTableViewEdition->getView()->insertGlobalAction("open");
+            ui.kUnitTableViewEdition->getView()->insertGlobalAction("open_report");
+            ui.kUnitTableViewEdition->getView()->insertGlobalAction();
             ui.kUnitTableViewEdition->getView()->insertGlobalAction("edit_delete");
             ui.kUnitTableViewEdition->getView()->insertGlobalAction();
+            ui.kUnitTableViewEdition->getView()->insertGlobalAction("edit_switch_highlight");
             ui.kUnitTableViewEdition->getView()->insertGlobalAction("edit_split_stock");
-            ui.kUnitTableViewEdition->getView()->insertGlobalAction();
-            ui.kUnitTableViewEdition->getView()->insertGlobalAction("open_report");
         }
 
         connect(ui.kUnitTableViewEdition->getView(), SIGNAL(clickEmptyArea()), this, SLOT(cleanEditor()));
-        connect(ui.kUnitTableViewEdition->getView(), SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onDoubleClickUnit()));
+        connect(ui.kUnitTableViewEdition->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
         connect(ui.kUnitTableViewEdition->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
     }
 
@@ -497,50 +503,6 @@ void SKGUnitPluginWidget::onModifyUnit()
     SKGMainPanel::displayErrorMessage(err);
 }
 
-void SKGUnitPluginWidget::onDoubleClickUnit()
-{
-    _SKGTRACEIN(10, "SKGUnitPluginWidget::onDoubleClick");
-
-    //Get selection
-    SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
-    if (selection.count() == 1) {
-        SKGUnitObject unit(selection.at(0));
-        int unitid = unit.getID();
-
-        //Build where clause and title
-        QString wc = "rc_unit_id=" % SKGServices::intToString(unitid);
-        QString title = i18nc("Noun, a list of items", "Operations with unit equal to '%1'",  unit.getName());
-
-        //Open
-        if (QApplication::keyboardModifiers() &Qt::ControlModifier && QApplication::keyboardModifiers() &Qt::ShiftModifier) {
-            //Call debug plugin
-            QDomDocument doc("SKGML");
-            QDomElement root = doc.createElement("parameters");
-            doc.appendChild(root);
-            root.setAttribute("sqlOrder", "SELECT * from v_operation_display WHERE " % wc);
-
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Debug plugin"), -1, doc.toString());
-        } else {
-            //Call operation plugin
-            QDomDocument doc("SKGML");
-            doc.setContent(getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
-            QDomElement root = doc.documentElement();
-            if (root.isNull()) {
-                root = doc.createElement("parameters");
-                doc.appendChild(root);
-            }
-
-            root.setAttribute("operationTable", "v_operation_display");
-            root.setAttribute("operationWhereClause", wc);
-            root.setAttribute("title", title);
-            root.setAttribute("title_icon", "view-currency-list");
-            root.setAttribute("currentPage", "-1");
-
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
-        }
-    }
-}
-
 SKGUnitObject::UnitDownloadMode SKGUnitPluginWidget::getDownloadModeFromSettings()
 {
     SKGUnitObject::UnitDownloadMode mode = SKGUnitObject::LAST;
