@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by SIDDHARTH SHARMA siddharth.kde@gmail.com        *
+ *   Copyright (C) 2010 by Guillaume DE BURE guillaume.debure@gmail.com        *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -29,35 +29,21 @@
 #include <QStringListModel>
 #include <KMessageBox>
 #include <sys/stat.h>
+#include <skgaccountobject.h>
+#include <skgruleobject.h>
 
 /**
-  * Name of a source
-  */
-#define SRC_ACCOUNTS "Accounts"
-/**
-  * Name of a source
-  */
-#define SRC_INCOMESANDEXPENDITURES "Incomes & Expenditures"
-/**
-  * Name of a source
-  */
-#define SRC_BANKS "Banks"
-/**
-  * Name of a source
-  */
-#define SRC_HIGHLIGHTED "Highlighted Operations"
-/**
-  * Name of a source
-  */
-#define SRC_SCHEDULED "Scheduled Operations"
-/**
-  * Name of a source
-  */
-#define SRC_UNITS "Units"
-/**
-  * Name of a source
-  */
-#define SRC_ADVICES "Advices"
+ * Data Sources names
+ */
+#define SRC_ACCOUNTS                "Accounts"
+#define SRC_INCOMESANDEXPENDITURES  "IncomesExpenditures"
+#define SRC_BANKS                   "Banks"
+#define SRC_HIGHLIGHTED             "Highlighted Operations"
+#define SRC_SCHEDULED               "Scheduled Operations"
+#define SRC_UNITS                   "Units"
+#define SRC_ADVICES                 "Advices"
+#define SRC_INTERESTS               "Interests"
+#define SRC_ALARMS                  "Alarms"
 
 SKGDataEngine::SKGDataEngine(QObject* parent, const QVariantList& args): DataEngine(parent, args), document(NULL) {}
 
@@ -97,6 +83,8 @@ bool SKGDataEngine::updateSourceEvent(const QString& source)
         return getUnitsData();
     } else if (source == SRC_ADVICES) {
         return getAdvicesData();
+    } else if (source == SRC_INTERESTS) {
+        return getInterestsData();
     }
     return false;
 }
@@ -145,15 +133,19 @@ bool SKGDataEngine::getIncomeExpenditureData()
     QString previousmonth = date.addMonths(-1).toString("yyyy-MM");
 
     SKGStringListList data;
-    SKGError err = document->executeSelectSqliteOrder("SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH FROM v_operation_display WHERE d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') AND t_TRANSFER='N' group by d_DATEMONTH, t_TYPEEXPENSE", data);
+    SKGError err = document->executeSelectSqliteOrder("SELECT d_DATEMONTH, t_TYPEEXPENSE, TOTAL(f_CURRENTAMOUNT) FROM v_operation_display WHERE t_TYPEEXPENSE IN ('+','-') AND d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') AND t_TRANSFER='N' group by d_DATEMONTH, t_TYPEEXPENSE", data);
 
     // We may receive an error from querying the SQLite database
     if (err) return false;
 
     // Put the data in the dataengine
     int nb = data.count();
-    for (int i = 0 ; i < nb ; ++i) {
-        setData(SRC_INCOMESANDEXPENDITURES, data.at(i).at(0), data.at(i).at(1));
+    for (int i = 1 ; i < nb ; ++i) {
+        QStringList values;
+        values << data.at(i).at(0); // month
+        values << data.at(i).at(1); // type (income or expense)
+        values << data.at(i).at(2); // amount
+        setData(SRC_INCOMESANDEXPENDITURES, SKGServices::intToString(i), values);
     }
     return true;
 }
@@ -277,6 +269,73 @@ bool SKGDataEngine::getAdvicesData()
     return true;
 }
 
+bool SKGDataEngine::getInterestsData()
+{
+    removeAllData(SRC_INTERESTS);
+    if (!document) return false;
+
+    SKGStringListList sqlResult;
+
+    // Fetch results in the database
+    SKGError err = document->executeSelectSqliteOrder("SELECT id,t_name FROM v_account WHERE t_close='N' AND EXISTS(select 1 from interest where interest.rd_account_id=v_account.id) ORDER BY t_name", sqlResult);
+
+    // We may receive an error from querying the SQLite database
+    if (err) return false;
+
+    // Put the data in the dataengine
+    int nb = sqlResult.count();
+    for (int i = 1 ; i < nb ; ++i) {
+        int account_id = SKGServices::stringToInt(sqlResult.at(i).at(0));
+
+        QStringList values;
+        SKGAccountObject account(document, account_id);
+
+        QList<SKGAccountObject::SKGInterestItem> oInterestList;
+        double oInterests = 0;
+        account.getInterestItems(oInterestList, oInterests);
+
+        values << sqlResult.at(i).at(1); // Account name
+        values << SKGServices::doubleToString(oInterests); // Interests
+
+        setData(SRC_INTERESTS, sqlResult.at(i).at(0), values);
+    }
+
+    return true;
+}
+
+
+bool SKGDataEngine::getAlarmsData()
+{
+    removeAllData(SRC_ALARMS);
+    if (!document) return false;
+
+    SKGStringListList sqlResult;
+
+    // Fetch results in the database
+    SKGError err = document->executeSelectSqliteOrder("SELECT id FROM v_rule WHERE t_action_type='A'", sqlResult);
+
+    // We may receive an error from querying the SQLite database
+    if (err) return false;
+
+    // Put the data in the dataengine
+    int nb = sqlResult.count();
+    for (int i = 1 ; i < nb ; ++i) {
+        int alarm_id = SKGServices::stringToInt(sqlResult.at(i).at(0));
+
+        QStringList values;
+        SKGRuleObject rule(document, alarm_id);
+
+        double alarm_limit = rule.getAlarmInfo().Amount;
+
+        values << SKGServices::doubleToString(alarm_limit); // Alarm limit
+
+        setData(SRC_ALARMS, sqlResult.at(i).at(0), values);
+    }
+
+    return true;
+}
+
+
 void SKGDataEngine::setDocument(SKGDocumentBank* iDocument)
 {
     document = iDocument;
