@@ -76,6 +76,7 @@ void SKGObjectModel::buidCache()
     m_ruleTable = (getRealTable() == "rule");
     m_categoryTable = (getRealTable() == "category");
     m_interestTable = (getRealTable() == "interest");
+    m_interestResultTable = (getRealTable() == "interest_result");
     m_budgetTable = (getRealTable() == "budget");
     m_budgetRuleTable = (getRealTable() == "budgetrule");
 
@@ -122,9 +123,7 @@ void SKGObjectModel::buidCache()
         m_fontDisabledScheduleColor = qVariantFromValue(pref.readEntry("fontFutureColor", QColor(Qt::gray)));
     }
 
-    if (m_operationTable || m_recurrentoperationTable || m_accountTable || m_ruleTable || m_categoryTable || m_payeeTable) {
-        m_iconFavorite = KIcon("rating");
-    }
+    m_iconFavorite = KIcon("rating");
 
     if (m_operationTable || m_recurrentoperationTable) {
         m_iconTransfer = KIcon("view-financial-transfer");
@@ -237,8 +236,7 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
     case Qt::UserRole: {
         QString att = m_listAttibutes[index.column()];
         QString val = obj->getAttribute(att);
-        if (((m_operationTable || m_recurrentoperationTable || m_trackerTable || m_accountTable || m_ruleTable || m_categoryTable || m_payeeTable) &&
-                (att == "t_bookmarked" || att == "t_status" || att == "i_NBRECURRENT" || att == "t_imported"))
+        if (((att == "t_bookmarked" || att == "t_status" || att == "i_NBRECURRENT" || att == "t_imported"))
                 || (att == "t_close")
                 || (att == "t_action_type")
            ) {
@@ -344,12 +342,12 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
     case Qt::DecorationRole: {
         //decoration
         QString att = m_listAttibutes[index.column()];
-        if (m_operationTable || m_recurrentoperationTable) {
+        if (att == "t_bookmarked") {
+            if (obj->getAttribute("t_bookmarked") == "Y")  return m_iconFavorite;
+        } else if (m_operationTable || m_recurrentoperationTable) {
             if (att == "t_mode") {
                 if (obj->getAttribute("t_TRANSFER") == "Y") return m_iconTransfer;
                 if (obj->getAttribute("i_group_id") != "0") return m_iconGroup;
-            } else if (att == "t_bookmarked") {
-                if (obj->getAttribute("t_bookmarked") == "Y")  return m_iconFavorite;
             } else if (att == "t_CATEGORY") {
                 if (SKGServices::stringToInt(obj->getAttribute("i_NBSUBCATEGORY")) > 1) return m_iconSplit;
             } else if (att == "i_NBRECURRENT" && m_operationTable) {
@@ -377,8 +375,6 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
                 if (val == "S") return m_iconSearch;
                 else if (val == "U") return m_iconUpdate;
                 else return m_iconAlarm;
-            } else if (att == "t_bookmarked") {
-                if (obj->getAttribute("t_bookmarked") == "Y")  return m_iconFavorite;
             }
         } else if (m_unitTable) {
             if (att == "f_CURRENTAMOUNT") {
@@ -405,21 +401,13 @@ else if(type == "I")  return KIcon("view-stock-account");
 else if(type == "A")  return KIcon("view-loan-asset");
 else if(type == "W")  return KIcon("kwalletmanager");
 else return KIcon();
-} */else if (att == "t_bookmarked") {
-                if (obj->getAttribute("t_bookmarked") == "Y")  return m_iconFavorite;
-            }
+} */
         } else if (m_categoryTable) {
             if (index.column() == 0) {
                 QString t_TYPEEXPENSE = obj->getAttribute("t_TYPEEXPENSE");
                 if (t_TYPEEXPENSE == "-") return m_iconCategoryMoins;
                 else if (t_TYPEEXPENSE == "+") return m_iconCategoryPlus;
                 return m_iconCategory;
-            } else if (att == "t_bookmarked") {
-                if (obj->getAttribute("t_bookmarked") == "Y")  return m_iconFavorite;
-            }
-        } else if (m_payeeTable) {
-            if (att == "t_bookmarked") {
-                if (obj->getAttribute("t_bookmarked") == "Y")  return m_iconFavorite;
             }
         } else if (m_budgetTable) {
             if (att == "f_DELTA" || att == "f_DELTABEFORETRANSFER") {
@@ -769,7 +757,7 @@ Qt::ItemFlags SKGObjectModel::flags(const QModelIndex& index) const
 
     if (index.isValid()) {
         QString att = m_listAttibutes[index.column()];
-        if (att == "t_bookmarked" || m_ruleTable || m_recurrentoperationTable) flags = flags & ~Qt::ItemIsEditable;
+        if (att == "t_bookmarked" || m_ruleTable || m_recurrentoperationTable || m_interestTable || m_interestResultTable) flags = flags & ~Qt::ItemIsEditable;
     }
 
     if (m_categoryTable || m_payeeTable || m_accountTable || m_unitTable || m_trackerTable) {
