@@ -38,7 +38,6 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* parent, SKGDocument* document, c
 {
     SKGServices::AttributeType attType = SKGServices::TEXT;
     if (document) attType = document->getAttributeType(attribute);
-    bool editable = !iModeUpdate || attribute.toLower() == attribute;
 
     //Build
     this->setAutoFillBackground(true);
@@ -82,7 +81,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* parent, SKGDocument* document, c
         if (cmbVal1) {
             cmbVal1->setObjectName(QString::fromUtf8("cmbVal1"));
             cmbVal1->setMinimumSize(QSize(100, 0));
-            cmbVal1->setEditable(editable);
+            cmbVal1->setEditable(true);
             QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
             sizePolicy.setHorizontalStretch(0);
             sizePolicy.setVerticalStretch(0);
@@ -96,7 +95,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* parent, SKGDocument* document, c
         if (cmbVal2) {
             cmbVal2->setObjectName(QString::fromUtf8("cmbVal2"));
             cmbVal2->setMinimumSize(QSize(100, 0));
-            cmbVal2->setEditable(editable);
+            cmbVal2->setEditable(true);
             QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
             sizePolicy.setHorizontalStretch(0);
             sizePolicy.setVerticalStretch(0);
@@ -190,7 +189,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* parent, SKGDocument* document, c
 
     QStringList listOps = SKGRuleObject::getListOfOperators(attType, m_updateMode ? SKGRuleObject::UPDATE : SKGRuleObject::SEARCH);
     int nb = listOps.count();
-    if (!editable && nb > 1) nb = 1;
+    if (!(!iModeUpdate || attribute.toLower() == attribute) && nb > 1) nb = 1;
     for (int i = 0; i < nb; ++i) {
         QString op = listOps.at(i);
         QString nlsOp = SKGRuleObject::getDisplayForOperator(op,
@@ -205,7 +204,6 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* parent, SKGDocument* document, c
     onOperatorChanged();
 }
 
-
 SKGPredicatCreator::~SKGPredicatCreator()
 {
     m_kOperator = NULL;
@@ -249,9 +247,9 @@ QString SKGPredicatCreator::getTextFromXml(const QString& iXML)
     doc.setContent(iXML);
     QDomElement root = doc.documentElement();
     QString output = SKGRuleObject::getDisplayForOperator(root.attribute("operator"),
-                     SKGServices::stringToSqlString(root.attribute("value")),
-                     SKGServices::stringToSqlString(root.attribute("value2")),
-                     SKGServices::stringToSqlString(root.attribute("att2s")));
+                     root.attribute("value"),
+                     root.attribute("value2"),
+                     root.attribute("att2s"));
     return output;
 }
 
