@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -59,11 +59,13 @@ public:
     /**
      * This enumerate defines type of account
      */
-    enum AccountType {CURRENT,  /**< to define a bank account*/
-                      CREDITCARD,   /**< to define a credit card account*/
-                      INVESTMENT,   /**< to define an account for investment */
-                      ASSETS,   /**< to define a assets account */
-                      OTHER     /**< other kind of account */
+    enum AccountType {CURRENT,   /**< to define a bank account*/
+                      CREDITCARD,/**< to define a credit card account*/
+                      INVESTMENT,/**< to define an account for investment */
+                      ASSETS,    /**< to define a assets account */
+                      OTHER,     /**< other kind of account */
+                      WALLET,    /**< to define a wallet account */
+                      LOAN       /**< to define a loan account */
                      };
 
     /**
@@ -95,7 +97,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGAccountObject& operator= (const SKGObjectBase &iObject);
+    virtual const SKGAccountObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
