@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+*   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -25,6 +25,8 @@
 #include "skgtraces.h"
 #include "skgcategoryobject.h"
 
+#include <klocale.h>
+
 SKGBudgetRuleObject::SKGBudgetRuleObject(SKGDocument* iDocument, int iID)
     : SKGObjectBase(iDocument, "v_budgetrule", iID)
 {
@@ -41,14 +43,14 @@ SKGBudgetRuleObject::SKGBudgetRuleObject(const SKGBudgetRuleObject& iObject)
 
 SKGBudgetRuleObject::SKGBudgetRuleObject(const SKGObjectBase& iObject)
 {
-    if(iObject.getRealTable() == "budgetrule") {
+    if (iObject.getRealTable() == "budgetrule") {
         copyFrom(iObject);
     } else {
         *this = SKGObjectBase(iObject.getDocument(), "v_budgetrule", iObject.getID());
     }
 }
 
-const SKGBudgetRuleObject& SKGBudgetRuleObject::operator= (const SKGObjectBase & iObject)
+const SKGBudgetRuleObject& SKGBudgetRuleObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -111,7 +113,7 @@ SKGError SKGBudgetRuleObject::setBudgetCategory(const SKGCategoryObject& iCatego
 
 SKGError SKGBudgetRuleObject::getBudgetCategory(SKGCategoryObject& oCategory) const
 {
-    return getDocument()->getObject("v_category", "id=" + getAttribute("rc_category_id"), oCategory);
+    return getDocument()->getObject("v_category", "id=" % getAttribute("rc_category_id"), oCategory);
 }
 
 SKGError SKGBudgetRuleObject::removeBudgetCategory()
@@ -132,7 +134,7 @@ SKGBudgetRuleObject::Condition SKGBudgetRuleObject::getCondition() const
 SKGError SKGBudgetRuleObject::setQuantity(double iQuantity, bool iAbsolute)
 {
     SKGError err = setAttribute("f_quantity", SKGServices::doubleToString(iQuantity));
-    if(err.isSucceeded()) err = setAttribute("t_absolute", iAbsolute ? "Y" : "N");
+    if (!err) err = setAttribute("t_absolute", iAbsolute ? "Y" : "N");
     return err;
 }
 
@@ -159,7 +161,7 @@ int SKGBudgetRuleObject::isCategoryChangeEnabled() const
 SKGError SKGBudgetRuleObject::setTransfer(SKGBudgetRuleObject::Mode iMode, const SKGCategoryObject& iCategory)
 {
     SKGError err = setAttribute("t_rule", iMode == NEXT ? "N" : iMode == CURRENT ? "C" : "Y");
-    if(err.isSucceeded()) err = setAttribute("rc_category_id_target", SKGServices::intToString(iCategory.getID()));;
+    if (!err) err = setAttribute("rc_category_id_target", SKGServices::intToString(iCategory.getID()));;
     return err;
 }
 
@@ -170,35 +172,35 @@ SKGBudgetRuleObject::Mode SKGBudgetRuleObject::getTransferMode() const
 
 SKGError SKGBudgetRuleObject::getTransferCategory(SKGCategoryObject& oCategory) const
 {
-    return getDocument()->getObject("v_category", "id=" + getAttribute("rc_category_id_target"), oCategory);
+    return getDocument()->getObject("v_category", "id=" % getAttribute("rc_category_id_target"), oCategory);
 }
 
 SKGError SKGBudgetRuleObject::processAllRules(SKGDocumentBank* iDocument)
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGBudgetRuleObject::processAllRules", err);
-    if(iDocument) {
+    if (iDocument) {
         //Initialize
         err = iDocument->executeSqliteOrder("UPDATE budget SET f_budgeted_modified=f_budgeted  WHERE f_budgeted_modified!=f_budgeted");
-        if(err.isSucceeded()) err = iDocument->executeSqliteOrder("UPDATE budget SET f_transferred=0  WHERE f_transferred!=0");
+        if (!err) err = iDocument->executeSqliteOrder("UPDATE budget SET f_transferred=0  WHERE f_transferred!=0");
 
         //Get budgets ordered by date
         SKGObjectBase::SKGListSKGObjectBase budgets;
-        if(err.isSucceeded()) err = iDocument->getObjects("v_budget", "length(t_RULES)>0 "
-                                        //"t_PERIOD<STRFTIME('%Y-%m', date('now')) AND t_PERIOD!=STRFTIME('%Y', date('now')) "
-                                        "ORDER BY t_PERIOD, id", budgets);
+        if (!err) err = iDocument->getObjects("v_budget", "length(t_RULES)>0 "
+                                                  //"t_PERIOD<STRFTIME('%Y-%m', date('now')) AND t_PERIOD!=STRFTIME('%Y', date('now')) "
+                                                  "ORDER BY t_PERIOD, id", budgets);
         int nb = budgets.count();
-        if(err.isSucceeded() && nb && iDocument) {
-            err = iDocument->beginTransaction("#INTERNAL#", nb);
-            for(int i = 0; err.isSucceeded() && i < nb; ++i) {
+        if (!err && nb && iDocument) {
+            err = iDocument->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Apply rules"), nb);
+            for (int i = 0; !err && i < nb; ++i) {
                 SKGBudgetObject bud = budgets.at(i);
                 err = bud.load(); //Reload to be sure that delta has been updated
-                if(err.isSucceeded()) err = bud.process();
+                if (!err) err = bud.process();
 
-                if(err.isSucceeded()) err = iDocument->stepForward(i + 1);
+                if (!err) err = iDocument->stepForward(i + 1);
             }
 
-            if(err.isSucceeded()) err = iDocument->endTransaction(true);
+            if (!err) err = iDocument->endTransaction(true);
             else  iDocument->endTransaction(false);
         }
     }
