@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -32,103 +32,100 @@
 #include <klocale.h>
 
 SKGOperationObject::SKGOperationObject(SKGDocument* iDocument, int iID) : SKGObjectBase(iDocument, "v_operation", iID)
-{
-}
+{}
 
 SKGOperationObject::~SKGOperationObject()
-{
-}
+{}
 
 SKGOperationObject::SKGOperationObject(const SKGOperationObject& iObject)
     : SKGObjectBase(iObject)
-{
-}
+{}
 
 SKGOperationObject::SKGOperationObject(const SKGObjectBase& iObject)
 {
-    if(iObject.getRealTable() == "operation") {
+    if (iObject.getRealTable() == "operation") {
         copyFrom(iObject);
     } else {
         *this = SKGObjectBase(iObject.getDocument(), "v_operation", iObject.getID());
     }
 }
 
-const SKGOperationObject& SKGOperationObject::operator= (const SKGObjectBase & iObject)
+const SKGOperationObject& SKGOperationObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
 }
 
-SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDate& iDate, bool iTemplateMode)
+SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDate& iDate, bool iTemplateMode) const
 {
     SKGError err;
     SKGTRACEINRC(20, "SKGOperationObject::duplicate", err);
     //Create the duplicated operation
     oOperation = SKGOperationObject(getDocument(), this->getID());  //To be sure the object is on v_operation
-    if(err.isSucceeded()) err = oOperation.load();
-    if(err.isSucceeded()) err = oOperation.resetID();
-    if(err.isSucceeded()) err = oOperation.setDate(iDate);
-    if(err.isSucceeded()) err = oOperation.setStatus(SKGOperationObject::NONE);
-    if(err.isSucceeded()) err = oOperation.setImported(false);
-    if(err.isSucceeded()) err = oOperation.setTemplate(iTemplateMode);
-    if(err.isSucceeded()) err = oOperation.setImportID("");
-    if(err.isSucceeded()) err = oOperation.bookmark(false);
-    if(err.isSucceeded()) err = oOperation.setNumber(0);
-    if(err.isSucceeded()) err = oOperation.setGroupOperation(oOperation);     //We have to ungroup first to be able to group after
-    if(err.isSucceeded()) err = oOperation.save(false, false);     //Just an insert + no reload (doesn't work if the )
+    if (!err) err = oOperation.load();
+    if (!err) err = oOperation.resetID();
+    if (!err) err = oOperation.setDate(iDate);
+    if (!err) err = oOperation.setStatus(SKGOperationObject::NONE);
+    if (!err) err = oOperation.setImported(false);
+    if (!err) err = oOperation.setTemplate(iTemplateMode);
+    if (!err) err = oOperation.setImportID("");
+    if (!err) err = oOperation.bookmark(false);
+    if (!err) err = oOperation.setNumber(0);
+    if (!err) err = oOperation.setGroupOperation(oOperation);    //We have to ungroup first to be able to group after
+    if (!err) err = oOperation.save(false, false);    //Just an insert + no reload (doesn't work if the )
 
     //Duplicate subop
-    if(err.isSucceeded()) {
+    if (!err) {
         SKGListSKGObjectBase subops;
         err = getSubOperations(subops);
         int nbsupops = subops.count();
-        for(int i = 0; err.isSucceeded() && i < nbsupops; ++i) {
+        for (int i = 0; !err && i < nbsupops; ++i) {
             SKGSubOperationObject subop = subops.at(i);
             err = subop.resetID();
-            if(err.isSucceeded()) err = subop.setParentOperation(oOperation);
-            if(err.isSucceeded()) err = subop.save(false);     //Just an insert
+            if (!err) err = subop.setParentOperation(oOperation);
+            if (!err) err = subop.save(false);    //Just an insert
         }
     }
 
     //Duplicate grouped operation to support recurrent transfers
-    if(err.isSucceeded()) {
+    if (!err) {
         SKGListSKGObjectBase goupops;
         err = getGroupedOperations(goupops);
         int nbgoupops = goupops.count();
-        for(int i = 0; err.isSucceeded() && i < nbgoupops; ++i) {
+        for (int i = 0; !err && i < nbgoupops; ++i) {
             SKGOperationObject groupop = goupops.at(i);
-            if(groupop != *this) {
+            if (groupop != *this) {
                 //Create the duplicated operation
                 SKGOperationObject newgroupop = groupop;
                 err = newgroupop.resetID();
-                if(err.isSucceeded()) err = newgroupop.setDate(iDate);
-                if(err.isSucceeded()) err = newgroupop.setStatus(SKGOperationObject::NONE);
-                if(err.isSucceeded()) err = newgroupop.setImported(false);
-                if(err.isSucceeded()) err = newgroupop.setTemplate(iTemplateMode);
-                if(err.isSucceeded()) err = newgroupop.setImportID("");
-                if(err.isSucceeded()) err = newgroupop.bookmark(false);
-                if(err.isSucceeded()) err = newgroupop.setNumber(0);
-                if(err.isSucceeded()) err = newgroupop.setGroupOperation(newgroupop);     //We have to ungroup first to be able to group after
-                if(err.isSucceeded()) err = newgroupop.setGroupOperation(oOperation);
-                if(err.isSucceeded()) err = newgroupop.save(false);     //Just an insert
+                if (!err) err = newgroupop.setDate(iDate);
+                if (!err) err = newgroupop.setStatus(SKGOperationObject::NONE);
+                if (!err) err = newgroupop.setImported(false);
+                if (!err) err = newgroupop.setTemplate(iTemplateMode);
+                if (!err) err = newgroupop.setImportID("");
+                if (!err) err = newgroupop.bookmark(false);
+                if (!err) err = newgroupop.setNumber(0);
+                if (!err) err = newgroupop.setGroupOperation(newgroupop);    //We have to ungroup first to be able to group after
+                if (!err) err = newgroupop.setGroupOperation(oOperation);
+                if (!err) err = newgroupop.save(false);    //Just an insert
 
                 //Duplicate subop
-                if(err.isSucceeded()) {
+                if (!err) {
                     SKGListSKGObjectBase subops;
                     err = groupop.getSubOperations(subops);
                     int nbsupops = subops.count();
-                    for(int i = 0; err.isSucceeded() && i < nbsupops; ++i) {
+                    for (int i = 0; !err && i < nbsupops; ++i) {
                         SKGSubOperationObject subop = subops.at(i);
                         err = subop.resetID();
-                        if(err.isSucceeded()) err = subop.setParentOperation(newgroupop);
-                        if(err.isSucceeded()) err = subop.save(false);     //Just an insert
+                        if (!err) err = subop.setParentOperation(newgroupop);
+                        if (!err) err = subop.save(false);    //Just an insert
                     }
                 }
             }
         }
     }
 
-    if(err.isSucceeded()) err = oOperation.load();
+    if (!err) err = oOperation.load();
     return err;
 }
 
@@ -136,7 +133,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
 SKGError SKGOperationObject::getParentAccount(SKGAccountObject& oAccount) const
 {
     SKGObjectBase objTmp;
-    SKGError err = getDocument()->getObject("v_account", "id=" + getAttribute("rd_account_id"), objTmp);
+    SKGError err = getDocument()->getObject("v_account", "id=" % getAttribute("rd_account_id"), objTmp);
     oAccount = objTmp;
     return err;
 }
@@ -146,10 +143,10 @@ SKGError SKGOperationObject::setParentAccount(const SKGAccountObject& iAccount)
     SKGError err;
     QString currentAccount = getAttribute("rd_account_id");
     QString newAccount = SKGServices::intToString(iAccount.getID());
-    if(newAccount == "0") err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::setParentAccount")));
+    if (newAccount == "0") err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::setParentAccount")));
     else {
-        if(newAccount != currentAccount) {
-            if(iAccount.isClosed()) err = SKGError(ERR_FAIL, i18nc("Error message",  "Impossible to add an operation in a closed account"));
+        if (newAccount != currentAccount) {
+            if (iAccount.isClosed()) err = SKGError(ERR_FAIL, i18nc("Error message",  "Impossible to add an operation in a closed account"));
             else err = setAttribute("rd_account_id", newAccount);
         }
     }
@@ -173,7 +170,7 @@ SKGError SKGOperationObject::setPayee(const SKGPayeeObject& iPayee)
 
 SKGError SKGOperationObject::getPayee(SKGPayeeObject& oPayee) const
 {
-    SKGError err = getDocument()->getObject("v_payee", "id=" + SKGServices::intToString(SKGServices::stringToInt(getAttribute("r_payee_id"))), oPayee);
+    SKGError err = getDocument()->getObject("v_payee", "id=" % SKGServices::intToString(SKGServices::stringToInt(getAttribute("r_payee_id"))), oPayee);
     return err;
 }
 
@@ -200,8 +197,8 @@ int SKGOperationObject::getNumber() const
 SKGOperationObject::OperationStatus SKGOperationObject::getStatus() const
 {
     QString t_status = getAttribute("t_status");
-    if(t_status == "Y") return SKGOperationObject::CHECKED;
-    else if(t_status == "P") return SKGOperationObject::POINTED;
+    if (t_status == "Y") return SKGOperationObject::CHECKED;
+    else if (t_status == "P") return SKGOperationObject::POINTED;
     return SKGOperationObject::NONE;
 }
 
@@ -222,7 +219,7 @@ QDate SKGOperationObject::getDate() const
 
 SKGError SKGOperationObject::getUnit(SKGUnitObject& oUnit) const
 {
-    SKGError err = getDocument()->getObject("v_unit", "id=" + getAttribute("rc_unit_id"), oUnit);
+    SKGError err = getDocument()->getObject("v_unit", "id=" % getAttribute("rc_unit_id"), oUnit);
     return err;
 }
 
@@ -238,42 +235,25 @@ bool SKGOperationObject::isInGroup() const
 
 bool SKGOperationObject::isTransfer(SKGOperationObject& oOperation) const
 {
+    SKGTRACEIN(10, "SKGOperationObject::isTransfer")
     SKGObjectBase::SKGListSKGObjectBase ops;
     getGroupedOperations(ops);
-    if(ops.count() == 2) {
-        //yes it is maybe a transfer
-        oOperation = (*this == SKGOperationObject(ops.at(0)) ? ops.at(1) : ops.at(0));
-
-        //Is in same group ?
-        if(getAttribute("i_group_id") != oOperation.getAttribute("i_group_id")) return false;
-
-        //2 ops in the group ?
-        SKGListSKGObjectBase oGroupedOperations;
-        getGroupedOperations(oGroupedOperations);
-        if(oGroupedOperations.count() != 2) return false;
-
-        //Check unit
-        if(getAttribute("rc_unit_id") != oOperation.getAttribute("rc_unit_id")) return false;
-
-        //Check sum
-        if(SKGServices::stringToDouble(getAttribute("f_QUANTITY")) != -SKGServices::stringToDouble(oOperation.getAttribute("f_QUANTITY"))) return false;
-    } else return false;
-
-    return true;
+    if (ops.count() == 2) oOperation = (*this == SKGOperationObject(ops.at(0)) ? ops.at(1) : ops.at(0));
+    return (getAttribute("t_TRANSFER") == "Y");
 }
 
 SKGError SKGOperationObject::getGroupedOperations(SKGListSKGObjectBase& oGroupedOperations) const
 {
     SKGError err;
     QString gpId1 = getAttribute("i_group_id");
-    if(gpId1 == "0") oGroupedOperations.clear();
-    else  err = getDocument()->getObjects("v_operation", "i_group_id=" + gpId1, oGroupedOperations);
+    if (gpId1 == "0") oGroupedOperations.clear();
+    else  err = getDocument()->getObjects("v_operation", "i_group_id=" % gpId1, oGroupedOperations);
     return err;
 }
 
 SKGError SKGOperationObject::getGroupOperation(SKGOperationObject& oOperation) const
 {
-    SKGError err = getDocument()->getObject("v_operation", "id=" + getAttribute("i_group_id"), oOperation);
+    SKGError err = getDocument()->getObject("v_operation", "id=" % getAttribute("i_group_id"), oOperation);
     return err;
 }
 
@@ -283,41 +263,41 @@ SKGError SKGOperationObject::setGroupOperation(const SKGOperationObject& iOperat
     SKGTRACEINRC(20, "SKGOperationObject::setGroupOperation", err);
 
     //Is it a remove group ?
-    if(iOperation == *this) {
+    if (iOperation == *this) {
         //Yes
         err = setAttribute("i_group_id", "0");
     } else {
         //No
         //Is a group already existing ?
         QString existingGroup = getAttribute("i_group_id");
-        if(existingGroup == "0" || existingGroup.isEmpty()) existingGroup = iOperation.getAttribute("i_group_id");
+        if (existingGroup == "0" || existingGroup.isEmpty()) existingGroup = iOperation.getAttribute("i_group_id");
 
-        if(existingGroup == "0" || existingGroup.isEmpty()) {
+        if (existingGroup == "0" || existingGroup.isEmpty()) {
             //No, we have to create a new group
             SKGStringListList result;
             err = getDocument()->executeSelectSqliteOrder("SELECT max(i_group_id) from operation", result);
-            if(err.isSucceeded()) {
+            if (!err) {
                 //Compute new group id
                 QString newIdGroup('1');
-                if(result.count() == 2) {
+                if (result.count() == 2) {
                     newIdGroup = SKGServices::intToString(SKGServices::stringToInt(result.at(1).at(0)) + 1);
                 }
 
                 //Set group id
                 SKGOperationObject op1 = SKGOperationObject(iOperation.getDocument(), iOperation.getID());
                 err = op1.setAttribute("i_group_id", newIdGroup);
-                if(err.isSucceeded()) err = op1.save();
+                if (!err) err = op1.save();
 
-                if(err.isSucceeded()) err = setAttribute("i_group_id", newIdGroup);
+                if (!err) err = setAttribute("i_group_id", newIdGroup);
 
             }
         } else {
             //Yes, all operation must be grouped
             SKGOperationObject op1 = iOperation;
             err = op1.setAttribute("i_group_id", existingGroup);
-            if(err.isSucceeded()) err = op1.save();
+            if (!err) err = op1.save();
 
-            if(err.isSucceeded()) err = setAttribute("i_group_id", existingGroup);
+            if (!err) err = setAttribute("i_group_id", existingGroup);
         }
 
     }
@@ -350,7 +330,7 @@ bool SKGOperationObject::isImported() const
 SKGError SKGOperationObject::setImportID(const QString& iImportID)
 {
     SKGError err = setAttribute("t_import_id", iImportID);
-    if(err.isSucceeded() && !iImportID.isEmpty()) err = setAttribute("t_imported", "T");
+    if (!err && !iImportID.isEmpty()) err = setAttribute("t_imported", "T");
     return err;
 }
 
@@ -378,7 +358,7 @@ int SKGOperationObject::getNbSubOperations() const
 SKGError SKGOperationObject::addSubOperation(SKGSubOperationObject& oSubOperation)
 {
     SKGError err;
-    if(getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::addSubOperation")));
+    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::addSubOperation")));
     else {
         oSubOperation = SKGSubOperationObject(getDocument());
         err = oSubOperation.setParentOperation(*this);
@@ -389,11 +369,11 @@ SKGError SKGOperationObject::addSubOperation(SKGSubOperationObject& oSubOperatio
 SKGError SKGOperationObject::getSubOperations(SKGListSKGObjectBase& oSubOperations) const
 {
     SKGError err;
-    if(getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::getSubOperations")));
+    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::getSubOperations")));
     else {
 
         err = getDocument()->getObjects("v_suboperation",
-                                        "rd_operation_id=" + SKGServices::intToString(getID()), oSubOperations);
+                                        "rd_operation_id=" % SKGServices::intToString(getID()), oSubOperations);
     }
     return err;
 }
@@ -408,9 +388,9 @@ double SKGOperationObject::getBalance() const
     double output = 0.0;
     SKGStringListList result;
     SKGError err = getDocument()->executeSelectSqliteOrder("SELECT TOTAL(f_CURRENTAMOUNT) FROM v_operation WHERE t_template='N' AND "
-                   "rd_account_id=" + getAttribute("rd_account_id") + " AND (d_date<'" + getAttribute("d_date") + "' OR "
-                   "(d_date='" + getAttribute("d_date") + "' AND id<=" + SKGServices::intToString(getID()) + "))", result);
-    if(err.isSucceeded()) {
+                   "rd_account_id=" % getAttribute("rd_account_id") % " AND (d_date<'" % getAttribute("d_date") % "' OR "
+                   "(d_date='" % getAttribute("d_date") % "' AND id<=" % SKGServices::intToString(getID()) % "))", result);
+    if (!err) {
         output = SKGServices::stringToDouble(result.at(1).at(0));
     }
 
@@ -424,27 +404,27 @@ double SKGOperationObject::getAmount(const QDate& iDate) const
 
     //Is the unit value already in cache ?
     double coef = 1;
-    QString val = getDocument()->getCachedValue("unitvalue-" + getAttribute("rc_unit_id"));
-    if(!val.isEmpty()) {
+    QString val = getDocument()->getCachedValue("unitvalue-" % getAttribute("rc_unit_id"));
+    if (!val.isEmpty()) {
         //Yes
         coef = SKGServices::stringToDouble(val);
     } else {
         //No
         SKGUnitObject unit;
-        if(getUnit(unit).isSucceeded()) coef = unit.getAmount(iDate);
+        if (getUnit(unit).isSucceeded()) coef = unit.getAmount(iDate);
     }
 
     return coef * quantity;
 }
 
-SKGError SKGOperationObject::addRecurrentOperation(SKGRecurrentOperationObject& oRecurrentOperation)
+SKGError SKGOperationObject::addRecurrentOperation(SKGRecurrentOperationObject& oRecurrentOperation) const
 {
     SKGError err;
-    if(getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::addRecurrentOperation")));
+    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::addRecurrentOperation")));
     else {
         oRecurrentOperation = SKGRecurrentOperationObject(getDocument());
         err = oRecurrentOperation.setParentOperation(*this);
-        if(err.isSucceeded()) oRecurrentOperation.setDate(getDate());
+        if (!err) oRecurrentOperation.setDate(getDate());
     }
     return err;
 }
@@ -452,28 +432,55 @@ SKGError SKGOperationObject::addRecurrentOperation(SKGRecurrentOperationObject&
 SKGError SKGOperationObject::getRecurrentOperations(SKGListSKGObjectBase& oRecurrentOperation) const
 {
     SKGError err;
-    if(getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::getRecurrentOperation")));
+    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::getRecurrentOperation")));
     else {
         err = getDocument()->getObjects("v_recurrentoperation",
-                                        "rd_operation_id=" + SKGServices::intToString(getID()), oRecurrentOperation);
+                                        "rd_operation_id=" % SKGServices::intToString(getID()), oRecurrentOperation);
     }
     return err;
 }
 
-SKGError SKGOperationObject::mergeAtttibute(const SKGOperationObject& iDeletedOne)
+SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOne)
 {
+    //Merge operation
     SKGError err = setDate(iDeletedOne.getDate());
-    if(err.isSucceeded()) err = setImportID(iDeletedOne.getImportID());
-    if(err.isSucceeded()) err = setAttribute("t_imported", iDeletedOne.getAttribute("t_imported"));
-    if(err.isSucceeded() && getComment().isEmpty()) err = setComment(iDeletedOne.getComment());
+    if (!err) err = setImportID(iDeletedOne.getImportID());
+    if (!err) err = setAttribute("t_imported", iDeletedOne.getAttribute("t_imported"));
+    if (!err && getComment().isEmpty()) err = setComment(iDeletedOne.getComment());
     SKGPayeeObject payee;
     getPayee(payee);
-    if(err.isSucceeded()) err = setPayee(payee);
-    if(err.isSucceeded() && getMode().isEmpty()) err = setMode(iDeletedOne.getMode());
-    if(err.isSucceeded() && !isBookmarked()) err = bookmark(iDeletedOne.isBookmarked());
-    if(err.isSucceeded() && !getNumber()) err = setNumber(iDeletedOne.getNumber());
-    if(err.isSucceeded()) err = save();
-    if(err.isSucceeded()) err = iDeletedOne.remove();
+    if (!err) err = setPayee(payee);
+    if (!err && getMode().isEmpty()) err = setMode(iDeletedOne.getMode());
+    if (!err && !isBookmarked()) err = bookmark(iDeletedOne.isBookmarked());
+    if (!err && !getNumber()) err = setNumber(iDeletedOne.getNumber());
+    if (!err) err = save();
+
+    //Merge suboperations
+    if (getCurrentAmount() != iDeletedOne.getCurrentAmount()) {
+        SKGObjectBase::SKGListSKGObjectBase subOps1;
+        if (!err) err = getSubOperations(subOps1);
+
+        SKGObjectBase::SKGListSKGObjectBase subOps2;
+        if (!err) err = iDeletedOne.getSubOperations(subOps2);
+
+        if (subOps2.count() == 1 && subOps1.count() == 1) {
+            //Change the quantity of the sub operation
+            SKGSubOperationObject so1 = subOps1.at(0);
+            SKGSubOperationObject so2 = subOps2.at(0);
+            if (!err) err = so1.setQuantity(so2.getQuantity());
+            if (!err) err = so1.save();
+        } else if (subOps2.count() >= 1 && subOps1.count() >= 1) {
+            //Add a split
+            SKGSubOperationObject so1;
+            if (!err) err = addSubOperation(so1);
+            if (!err) err = so1.setQuantity(iDeletedOne.getCurrentAmount() - getCurrentAmount());
+            if (!err) err = so1.save();
+        }
+        if (!err) getDocument()->sendMessage(i18nc("An information message",  "Amount has been changed to be aligned with the imported operation"), true);
+    }
+
+    //Delete useless operation
+    if (!err) err = iDeletedOne.remove(false);
     return err;
 }
 
@@ -483,12 +490,12 @@ SKGError SKGOperationObject::mergeSuboperations(const SKGOperationObject& iDelet
     SKGObjectBase::SKGListSKGObjectBase subops;
     err = iDeletedOne.getSubOperations(subops);
     int nb = subops.count();
-    for(int i = 0; err.isSucceeded() && i < nb; ++i) {
+    for (int i = 0; !err && i < nb; ++i) {
         SKGSubOperationObject subop = subops.at(i);
         err = subop.setParentOperation(*this);
-        if(err.isSucceeded()) err = subop.save();
+        if (!err) err = subop.save();
     }
-    if(err.isSucceeded()) err = iDeletedOne.remove();
+    if (!err) err = iDeletedOne.remove();
     return err;
 }
 
