@@ -56,6 +56,11 @@ SKGRuleObject::~SKGRuleObject()
 {
 }
 
+QString SKGRuleObject::getDisplayName() const
+{
+    return getSearchDescription();
+}
+
 SKGError SKGRuleObject::bookmark(bool iBookmark)
 {
     return setAttribute("t_bookmarked", iBookmark ? "Y" : "N");
@@ -452,9 +457,10 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                 if (!element.isNull()) {
                     //Build element description
                     QString elementDescription;
-                    QString attribute = SKGServices::stringToSqlString(element.attribute("attribute"));
+                    QString attribute = element.attribute("attribute");
                     QString propName;
                     if (iSQL) {
+                        attribute = SKGServices::stringToSqlString(attribute);
                         if (attribute.startsWith(QLatin1String("p_"))) {
                             //Case property
                             propName = attribute.right(attribute.length() - 2);
@@ -482,11 +488,11 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                             elementDescription += ' ';
                         }
 
-                        QString tmp = SKGServices::stringToSqlString(element.attribute("att2s"));
-                        if (tmp.isEmpty()) tmp = SKGServices::stringToSqlString(element.attribute("operator2"));
+                        QString tmp = element.attribute("att2s");
+                        if (tmp.isEmpty()) tmp = element.attribute("operator2");
                         QString part = SKGRuleObject::getDisplayForOperator(element.attribute("operator"),
-                                       SKGServices::stringToSqlString(element.attribute("value")),
-                                       SKGServices::stringToSqlString(element.attribute("value2")),
+                                       element.attribute("value"),
+                                       element.attribute("value2"),
                                        tmp);
 
                         elementDescription += part;
@@ -495,8 +501,9 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                     elementDescription = elementDescription.replace("#ATT#", attribute);
 
                     //Att2
-                    QString attribute2 = SKGServices::stringToSqlString(element.attribute("att2"));
+                    QString attribute2 = element.attribute("att2");
                     if (iSQL) {
+                        attribute2 = SKGServices::stringToSqlString(attribute2);
                         if (attribute2.startsWith(QLatin1String("p_"))) {
                             QString propertyName = attribute2.right(attribute2.length() - 2);
                             attribute2 = "IFNULL((SELECT v_operation_prop.i_PROPVALUE FROM v_operation_prop WHERE v_operation_prop.id=operation.id AND v_operation_prop.i_PROPPNAME='" % SKGServices::stringToSqlString(propertyName) % "'),'')";
@@ -515,16 +522,43 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                                 QString sqlOrder;
                                 if (attribute == "t_REALCATEGORY") {
                                     elementDescription.replace(attribute, "t_fullname");
-                                    output.push_back("UPDATE suboperation set r_category_id=IFNULL((SELECT id FROM category WHERE " % elementDescription % "),0) WHERE i_tmp=1");
+
+                                    QString parentcat;
+                                    QString cat = element.attribute("value");
+                                    bool stop = false;
+                                    while (!stop) {
+                                        int posSeparator = cat.indexOf(OBJECTSEPARATOR);
+                                        if (posSeparator == -1) {
+                                            if (parentcat.isEmpty())
+                                                output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(cat) % "', 0)");
+                                            else output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(cat) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
+                                            stop = true;
+                                        } else {
+                                            //Get first and second parts of the branch
+                                            QString first = cat.mid(0, posSeparator);
+                                            QString second = cat.mid(posSeparator + QString(OBJECTSEPARATOR).length(), cat.length() - posSeparator - QString(OBJECTSEPARATOR).length());
+                                            if (parentcat.isEmpty())
+                                                output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(first) % "', 0)");
+                                            else output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(first) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
+
+                                            if (parentcat.isEmpty()) parentcat = first;
+                                            else parentcat = parentcat % OBJECTSEPARATOR % first;
+                                            cat = second;
+                                        }
+                                    }
+                                    output.push_back("UPDATE suboperation set r_category_id=(SELECT id FROM category WHERE " % elementDescription % ") WHERE i_tmp=1");
                                 } else if (attribute == "t_ACCOUNT") {
                                     elementDescription.replace(attribute, "t_name");
-                                    output.push_back("UPDATE operation set rd_account_id=IFNULL((SELECT id FROM account WHERE " % elementDescription % "),0) WHERE i_tmp=1");
+                                    output.push_back("INSERT OR IGNORE INTO account (t_name, rd_bank_id) VALUES ('" % SKGServices::stringToSqlString(element.attribute("value")) % "', (SELECT MIN(id) FROM bank))");
+                                    output.push_back("UPDATE operation set rd_account_id=(SELECT id FROM account WHERE " % elementDescription % ") WHERE i_tmp=1");
                                 } else if (attribute == "t_PAYEE") {
                                     elementDescription.replace(attribute, "t_name");
-                                    output.push_back("UPDATE operation set r_payee_id=IFNULL((SELECT id FROM payee WHERE " % elementDescription % "),0) WHERE i_tmp=1");
+                                    output.push_back("INSERT OR IGNORE INTO payee (t_name) VALUES ('" % SKGServices::stringToSqlString(element.attribute("value")) % "')");
+                                    output.push_back("UPDATE operation set r_payee_id=(SELECT id FROM payee WHERE " % elementDescription % ") WHERE i_tmp=1");
                                 } else if (attribute == "t_REALREFUND") {
                                     elementDescription.replace(attribute, "t_name");
-                                    output.push_back("UPDATE suboperation set r_refund_id=IFNULL((SELECT id FROM refund WHERE " % elementDescription % "),0) WHERE i_tmp=1");
+                                    output.push_back("INSERT OR IGNORE INTO refund (t_name) VALUES ('" % SKGServices::stringToSqlString(element.attribute("value")) % "')");
+                                    output.push_back("UPDATE suboperation set r_refund_id=(SELECT id FROM refund WHERE " % elementDescription % ") WHERE i_tmp=1");
                                 } else if (element.attribute("attribute").startsWith(QLatin1String("p_"))) {
                                     output.push_back("INSERT OR IGNORE INTO parameters (t_uuid_parent, t_name, i_tmp) SELECT o.id||'-operation', '" % SKGServices::stringToSqlString(propName) % "', 1 FROM operation o WHERE o.i_tmp=1");
                                     output.push_back("UPDATE parameters set " % elementDescription % " WHERE i_tmp=1 AND t_name='" % SKGServices::stringToSqlString(propName) % "' AND NOT(" % elementDescription % ')');
