@@ -1069,73 +1069,78 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
             }
         } else {
             //ALTERNATIVE MODE
-            //Read source file
-            QHash< QString, QString > properties;
-            err = SKGServices::readPropertyFile(KStandardDirs().findResource("data", "skrooge/quotes/" % source % ".txt"), properties);
+            QString fileName = KStandardDirs().findResource("data", "skrooge/quotes/" % source % ".txt");
+            if (fileName.isEmpty()) {
+                err = SKGError(ERR_FAIL, i18nc("Error message", "Source of download %1 not installed.", source));
+            } else {
+                //Read source file
+                QHash< QString, QString > properties;
+                err = SKGServices::readPropertyFile(fileName, properties);
 
-            if (!err) {
-                QString path = properties["url"].replace("%1", code);
-                QString mode = properties["mode"].toUpper();
-                QString price = properties["price"].replace("%1", code);
-                QString date = properties["date"].replace("%1", code);
-                QString dateFormat = properties["dateformat"];
+                if (!err) {
+                    QString path = properties["url"].replace("%1", code);
+                    QString mode = properties["mode"].toUpper();
+                    QString price = properties["price"].replace("%1", code);
+                    QString date = properties["date"].replace("%1", code);
+                    QString dateFormat = properties["dateformat"];
 
-                //Download url
-                KUrl url(path);
-                QString tmpFile;
-                if (!err && KIO::NetAccess::download(url, tmpFile, NULL)) {
-                    //Open file
-                    QFile file(tmpFile);
-                    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-                        doc->sendMessage(i18nc("An information message", "Open file '%1' failed", tmpFile));
-                    } else {
-                        QTextStream stream(&file);
+                    //Download url
+                    KUrl url(path);
+                    QString tmpFile;
+                    if (!err && KIO::NetAccess::download(url, tmpFile, NULL)) {
+                        //Open file
+                        QFile file(tmpFile);
+                        if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                            doc->sendMessage(i18nc("An information message", "Open file '%1' failed", tmpFile));
+                        } else {
+                            QTextStream stream(&file);
 
-                        //Parse data
-                        QRegExp priceRegExp(price, Qt::CaseInsensitive);
-                        QRegExp dateRegExp(date, Qt::CaseInsensitive);
+                            //Parse data
+                            QRegExp priceRegExp(price, Qt::CaseInsensitive);
+                            QRegExp dateRegExp(date, Qt::CaseInsensitive);
 
-                        //Read data
-                        int nbLoaded = 0;
-                        while (!stream.atEnd() && !err && (nbLoaded < nbMaxValues || nbMaxValues == 0)) {
-                            //Read line
-                            QString data = (mode == "CSV" ? stream.readLine() : stream.readAll()).trimmed();
-                            if (!data.isEmpty()) {
-                                SKGTRACEL(1) << "Downloaded data from [" << path << "]=[" << data << "]" << endl;
+                            //Read data
+                            int nbLoaded = 0;
+                            while (!stream.atEnd() && !err && (nbLoaded < nbMaxValues || nbMaxValues == 0)) {
+                                //Read line
+                                QString data = (mode == "CSV" ? stream.readLine() : stream.readAll()).trimmed();
+                                if (!data.isEmpty()) {
+                                    SKGTRACEL(1) << "Downloaded data from [" << path << "]=[" << data << "]" << endl;
 
-                                double val = 0.0;
-                                if (priceRegExp.indexIn(data) > -1) val = SKGServices::stringToDouble(priceRegExp.cap(1));
-                                QString d;
-                                if (dateRegExp.indexIn(data) > -1) d = dateRegExp.cap(1);
-                                SKGTRACEL(1) << "Price found=[" << val << "]" << endl;
-                                SKGTRACEL(1) << "Date found=[" << d << "]" << endl;
+                                    double val = 0.0;
+                                    if (priceRegExp.indexIn(data) > -1) val = SKGServices::stringToDouble(priceRegExp.cap(1));
+                                    QString d;
+                                    if (dateRegExp.indexIn(data) > -1) d = dateRegExp.cap(1);
+                                    SKGTRACEL(1) << "Price found=[" << val << "]" << endl;
+                                    SKGTRACEL(1) << "Date found=[" << d << "]" << endl;
 
-                                //Set value
-                                if (val) {
-                                    QDate ds = QDate::fromString(d, dateFormat);
-                                    if (!ds.isValid()) ds = QDate::currentDate();
+                                    //Set value
+                                    if (val) {
+                                        QDate ds = QDate::fromString(d, dateFormat);
+                                        if (!ds.isValid()) ds = QDate::currentDate();
 
-                                    //Creation or update of the value
-                                    SKGUnitValueObject value;
-                                    if (!err) err = addUnitValue(value);
-                                    if (!err) err = value.setDate(ds);
-                                    if (!err) err = value.setQuantity(invert && val != 0 ? 1 / val : val);
-                                    if (!err) err = value.save();
+                                        //Creation or update of the value
+                                        SKGUnitValueObject value;
+                                        if (!err) err = addUnitValue(value);
+                                        if (!err) err = value.setDate(ds);
+                                        if (!err) err = value.setQuantity(invert && val != 0 ? 1 / val : val);
+                                        if (!err) err = value.save();
 
-                                    nbLoaded++;
+                                        nbLoaded++;
+                                    }
                                 }
                             }
+                            if (nbLoaded == 0) err = doc->sendMessage(i18nc("Information message", "Price not found for '%1' with regular expression '%2'", getName(), SKGServices::stringToHtml(price))); //TODO does not work with html
+
+                            //close file
+                            file.close();
                         }
-                        if (nbLoaded == 0) err = doc->sendMessage(i18nc("Information message", "Price not found for '%1' with regular expression '%2'", getName(), SKGServices::stringToHtml(price))); //TODO does not work with html
 
-                        //close file
-                        file.close();
+                        //Remove tmp file
+                        KIO::NetAccess::removeTempFile(tmpFile);
+                    } else {
+                        doc->sendMessage(i18nc("An information message", "Open url '%1' failed: %2", path, KIO::NetAccess::lastErrorString()));
                     }
-
-                    //Remove tmp file
-                    KIO::NetAccess::removeTempFile(tmpFile);
-                } else {
-                    doc->sendMessage(i18nc("An information message", "Open url '%1' failed: %2", path, KIO::NetAccess::lastErrorString()));
                 }
             }
         }
