@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,7 +24,7 @@
 #include <qlayout.h>
 #include <qwidget.h>
 
-SKGFlowLayout::SKGFlowLayout(QWidget *parent, int margin, int hSpacing, int vSpacing)
+SKGFlowLayout::SKGFlowLayout(QWidget* parent, int margin, int hSpacing, int vSpacing)
     : QLayout(parent), m_hSpace(hSpacing), m_vSpace(vSpacing)
 {
     setContentsMargins(margin, margin, margin, margin);
@@ -38,12 +38,12 @@ SKGFlowLayout::SKGFlowLayout(int margin, int hSpacing, int vSpacing)
 
 SKGFlowLayout::~SKGFlowLayout()
 {
-    QLayoutItem *item;
-    while((item = takeAt(0)))
+    QLayoutItem* item;
+    while ((item = takeAt(0)))
         delete item;
 }
 
-void SKGFlowLayout::addItem(QLayoutItem *item)
+void SKGFlowLayout::addItem(QLayoutItem* item)
 {
     m_itemList.append(item);
 }
@@ -56,7 +56,7 @@ void SKGFlowLayout::setSpacing(int space)
 
 int SKGFlowLayout::horizontalSpacing() const
 {
-    if(m_hSpace >= 0) {
+    if (m_hSpace >= 0) {
         return m_hSpace;
     } else {
         return smartSpacing(QStyle::PM_LayoutHorizontalSpacing);
@@ -65,7 +65,7 @@ int SKGFlowLayout::horizontalSpacing() const
 
 int SKGFlowLayout::verticalSpacing() const
 {
-    if(m_vSpace >= 0) {
+    if (m_vSpace >= 0) {
         return m_vSpace;
     } else {
         return smartSpacing(QStyle::PM_LayoutVerticalSpacing);
@@ -77,14 +77,14 @@ int SKGFlowLayout::count() const
     return m_itemList.size();
 }
 
-QLayoutItem *SKGFlowLayout::itemAt(int index) const
+QLayoutItem* SKGFlowLayout::itemAt(int index) const
 {
     return m_itemList.value(index);
 }
 
-QLayoutItem *SKGFlowLayout::takeAt(int index)
+QLayoutItem* SKGFlowLayout::takeAt(int index)
 {
-    if(index >= 0 && index < m_itemList.size())
+    if (index >= 0 && index < m_itemList.size())
         return m_itemList.takeAt(index);
     else
         return 0;
@@ -106,7 +106,7 @@ int SKGFlowLayout::heightForWidth(int width) const
     return height;
 }
 
-void SKGFlowLayout::setGeometry(const QRect &rect)
+void SKGFlowLayout::setGeometry(const QRect& rect)
 {
     QLayout::setGeometry(rect);
     doLayout(rect, false);
@@ -128,7 +128,7 @@ QSize SKGFlowLayout::minimumSize() const
     return size;
 }
 
-int SKGFlowLayout::doLayout(const QRect &rect, bool testOnly) const
+int SKGFlowLayout::doLayout(const QRect& rect, bool testOnly) const
 {
     int left, top, right, bottom;
     getContentsMargins(&left, &top, &right, &bottom);
@@ -140,60 +140,61 @@ int SKGFlowLayout::doLayout(const QRect &rect, bool testOnly) const
     int y1 = y;
 
     foreach(QLayoutItem * item, m_itemList) {
-        QWidget *wid = item->widget();
+        QWidget* wid = item->widget();
+        if (wid) {
+            //Get spaces
+            int spaceX = horizontalSpacing();
+            if (spaceX == -1) spaceX = wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Horizontal);
 
-        //Get spaces
-        int spaceX = horizontalSpacing();
-        if(spaceX == -1) spaceX = wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Horizontal);
+            int spaceY = verticalSpacing();
+            if (spaceY == -1) spaceY = wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Vertical);
 
-        int spaceY = verticalSpacing();
-        if(spaceY == -1) spaceY = wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Vertical);
+            //Try option
+            bool optionUsed = false;
+            if (lineHeight && x1) {
+                int nextX = x1 + item->sizeHint().width() + spaceX;
+                if (nextX <= x && y1 - y + item->sizeHint().height() <= lineHeight) {
+                    optionUsed = true;
 
-        //Try option
-        bool optionUsed = false;
-        if(lineHeight && x1) {
-            int nextX = x1 + item->sizeHint().width() + spaceX;
-            if(nextX <= x && y1 - y + item->sizeHint().height() <= lineHeight) {
-                optionUsed = true;
+                    //Position item
+                    if (!testOnly) item->setGeometry(QRect(QPoint(x1, y1), item->sizeHint()));
+
+                    x1 = nextX;
+                }
+            }
+
+            if (!optionUsed) {
+                int nextX = x + item->sizeHint().width() + spaceX;
+                if (nextX - spaceX > effectiveRect.right() && lineHeight > 0) {
+                    x = effectiveRect.x();
+                    y = y + lineHeight + spaceY;
+                    nextX = x + item->sizeHint().width() + spaceX;
+                    lineHeight = 0;
+                }
 
                 //Position item
-                if(!testOnly) item->setGeometry(QRect(QPoint(x1, y1), item->sizeHint()));
+                if (!testOnly) item->setGeometry(QRect(QPoint(x, y), item->sizeHint()));
 
-                x1 = nextX;
+                x1 = x;
+                y1 = y + item->sizeHint().height() + spaceY;
+                x = nextX;
+                lineHeight = qMax(lineHeight, item->sizeHint().height());
             }
         }
-
-        if(!optionUsed) {
-            int nextX = x + item->sizeHint().width() + spaceX;
-            if(nextX - spaceX > effectiveRect.right() && lineHeight > 0) {
-                x = effectiveRect.x();
-                y = y + lineHeight + spaceY;
-                nextX = x + item->sizeHint().width() + spaceX;
-                lineHeight = 0;
-            }
-
-            //Position item
-            if(!testOnly) item->setGeometry(QRect(QPoint(x, y), item->sizeHint()));
-
-            x1 = x;
-            y1 = y + item->sizeHint().height() + spaceY;
-            x = nextX;
-            lineHeight = qMax(lineHeight, item->sizeHint().height());
-        }
     }
     return y + lineHeight - rect.y() + bottom;
 }
 
 int SKGFlowLayout::smartSpacing(QStyle::PixelMetric pm) const
 {
-    QObject *parent = this->parent();
-    if(!parent) {
+    QObject* parent = this->parent();
+    if (!parent) {
         return -1;
-    } else if(parent->isWidgetType()) {
-        QWidget *pw = static_cast<QWidget *>(parent);
-        return pw->style()->pixelMetric(pm, 0, pw);
+    } else if (parent->isWidgetType()) {
+        QWidget* pw = static_cast<QWidget*>(parent);
+        return pw ? pw->style()->pixelMetric(pm, 0, pw) : 0;
     } else {
-        return static_cast<QLayout *>(parent)->spacing();
+        return static_cast<QLayout*>(parent)->spacing();
     }
 }
 
