@@ -541,13 +541,16 @@ void SKGMainPanel::processArguments(const QStringList& iArgument)
     }
 }
 
-void SKGMainPanel::registedGlobalAction(const QString& iIdentifier, KAction* iAction)
+void SKGMainPanel::registerGlobalAction(const QString& iIdentifier, KAction* iAction)
 {
     m_registeredGlogalAction[iIdentifier] = iAction;
 }
 
 KAction* SKGMainPanel::getGlobalAction(const QString& iIdentifier)
 {
+    if (!m_registeredGlogalAction.contains(iIdentifier)) {
+        SKGTRACE << "WARNING: Actione [" << iIdentifier << "]" << endl;
+    }
     return m_registeredGlogalAction[iIdentifier];
 }
 
@@ -590,7 +593,7 @@ void SKGMainPanel::setupActions()
     m_addTabAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_W);
     connect(m_addTabAction, SIGNAL(triggered()), this, SLOT(addTab()));
 
-    registedGlobalAction("tab-new-background", m_addTabAction);
+    registerGlobalAction("tab-new-background", m_addTabAction);
 
     m_actLock = new KAction(KIcon("document-encrypt"), i18nc("Verb", "Lock panels"), this);
     actionCollection()->addAction(QLatin1String("view_lock"), m_actLock);
@@ -603,7 +606,7 @@ void SKGMainPanel::setupActions()
     //
     m_closePageAction = actionCollection()->addAction(KStandardAction::Close, "tab_close", this, SLOT(closePage()));
 
-    registedGlobalAction("tab_close", m_closePageAction);
+    registerGlobalAction("tab_close", m_closePageAction);
 
     //
     m_closeAllPagesAction = new KAction(KIcon("window-close"), i18nc("Noun, user action", "Close All"), this);
@@ -611,7 +614,7 @@ void SKGMainPanel::setupActions()
     m_closeAllPagesAction->setShortcut(Qt::ALT + Qt::Key_W);
     connect(m_closeAllPagesAction, SIGNAL(triggered()), this, SLOT(closeAllPages()));
 
-    registedGlobalAction("tab_closeall", m_closeAllPagesAction);
+    registerGlobalAction("tab_closeall", m_closeAllPagesAction);
 
     //
     m_closeAllOtherPagesAction = new KAction(KIcon("window-close"), i18nc("Noun, user action", "Close All Other"), this);
@@ -619,7 +622,7 @@ void SKGMainPanel::setupActions()
     m_closeAllOtherPagesAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_W);
     connect(m_closeAllOtherPagesAction, SIGNAL(triggered()), this, SLOT(closeAllOtherPages()));
 
-    registedGlobalAction("tab_closeallother", m_closeAllOtherPagesAction);
+    registerGlobalAction("tab_closeallother", m_closeAllOtherPagesAction);
 
     //
     m_saveDefaultStateAction = new KAction(KIcon("document-save"), i18nc("Noun, user action", "Save page state"), this);
@@ -627,7 +630,7 @@ void SKGMainPanel::setupActions()
     m_saveDefaultStateAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_S);
     connect(m_saveDefaultStateAction, SIGNAL(triggered()), this, SLOT(saveDefaultState()));
 
-    registedGlobalAction("tab_savedefaultstate", m_saveDefaultStateAction);
+    registerGlobalAction("tab_savedefaultstate", m_saveDefaultStateAction);
 
     //
     m_resetDefaultStateAction = new KAction(KIcon("edit-clear"), i18nc("Noun, user action", "Reset page state"), this);
@@ -635,7 +638,7 @@ void SKGMainPanel::setupActions()
     m_resetDefaultStateAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_R);
     connect(m_resetDefaultStateAction, SIGNAL(triggered()), this, SLOT(resetDefaultState()));
 
-    registedGlobalAction("tab_resetdefaultstate", m_resetDefaultStateAction);
+    registerGlobalAction("tab_resetdefaultstate", m_resetDefaultStateAction);
 
     //
     QStringList overlay;
@@ -645,14 +648,14 @@ void SKGMainPanel::setupActions()
     connect(m_overwriteBookmarkStateAction, SIGNAL(triggered()), this, SLOT(overwriteBookmarkState()));
     m_overwriteBookmarkStateAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_S);
 
-    registedGlobalAction("tab_overwritebookmark", m_overwriteBookmarkStateAction);
+    registerGlobalAction("tab_overwritebookmark", m_overwriteBookmarkStateAction);
 
     //
     m_configureAction = new KAction(KIcon("configure"), i18nc("Noun, user action", "Configure..."), this);
     actionCollection()->addAction(QLatin1String("tab_configure"), m_configureAction);
     connect(m_configureAction, SIGNAL(triggered()), this, SLOT(optionsPreferences()));
 
-    registedGlobalAction("tab_configure", m_configureAction);
+    registerGlobalAction("tab_configure", m_configureAction);
 
     m_tipOfDayAction = KStandardAction::tipOfDay(this, SLOT(onTipOfDay()), actionCollection());
 
@@ -665,7 +668,7 @@ void SKGMainPanel::setupActions()
     connect(m_buttonMenu , SIGNAL(aboutToShow()), this, SLOT(onShowButtonMenu()));
     m_buttonMenuAction->setDelayed(false);
 
-    registedGlobalAction("view_menu", m_buttonMenuAction);
+    registerGlobalAction("view_menu", m_buttonMenuAction);
 
     m_showMenuBarAction = KStandardAction::showMenubar(this, SLOT(onShowMenuBar()), actionCollection());
 
@@ -688,7 +691,7 @@ void SKGMainPanel::setupActions()
     m_previousAction->setStickyMenu(false);
     m_previousAction->setData(0);
 
-    registedGlobalAction("go_previous", m_previousAction);
+    registerGlobalAction("go_previous", m_previousAction);
 
     //
     m_nextAction = new KToolBarPopupAction(KIcon("go-next"), i18nc("Noun, user action", "Next"), this);
@@ -702,12 +705,12 @@ void SKGMainPanel::setupActions()
     m_nextAction->setStickyMenu(false);
     m_nextAction->setData(0);
 
-    registedGlobalAction("go_next", m_nextAction);
+    registerGlobalAction("go_next", m_nextAction);
 
     //
     m_fullScreenAction = actionCollection()->addAction(KStandardAction::FullScreen, "fullscreen", this, SLOT(actionFullScreen()));
 
-    registedGlobalAction("fullscreen", m_fullScreenAction);
+    registerGlobalAction("fullscreen", m_fullScreenAction);
 
 
     //
@@ -1714,8 +1717,8 @@ QString SKGMainPanel::getSaveFileName(const QString& startDir, const QString& fi
     QString fileName;
     if (iCodec) {
         QString lastCodecUsed = QTextCodec::codecForLocale()->name();
-        KEncodingFileDialog::Result result = KEncodingFileDialog::getSaveFileNameAndEncoding(lastCodecUsed, startDir, filter , parent, caption);
-        if (result.fileNames.count()) fileName = result.fileNames.at(0);
+        KEncodingFileDialog::Result result = KEncodingFileDialog::getSaveUrlAndEncoding(lastCodecUsed, startDir, filter , parent, caption);
+        if (result.URLs.count()) fileName = result.URLs.at(0).pathOrUrl();
         *iCodec = result.encoding;
     } else {
         fileName = KFileDialog::getSaveFileName(KUrl(startDir), filter , parent, caption);
