@@ -279,7 +279,7 @@ public Q_SLOTS:
      * @param iIdentifier identifier of the action
      * @param iAction action pointer
      */
-    virtual void registedGlobalAction(const QString& iIdentifier, KAction* iAction);
+    virtual void registerGlobalAction(const QString& iIdentifier, KAction* iAction);
 
     /**
      * Get a registered global action
