@@ -379,6 +379,15 @@ void SKGObjectModelBase::refresh()
     QApplication::restoreOverrideCursor();
 }
 
+bool SKGObjectModelBase::hasChildren(const QModelIndex& parent) const
+{
+    if (parent.column() > 0) return false;
+    _SKGTRACEIN(10, "SKGObjectModelBase::hasChildren");
+
+    if(parent.isValid() && m_parentAttribute.isEmpty() && m_groupby.isEmpty()) return false; 
+    return QAbstractItemModel::hasChildren(parent);
+}
+
 int SKGObjectModelBase::rowCount(const QModelIndex& parent) const
 {
     if (parent.column() > 0) return 0;
@@ -735,7 +744,8 @@ bool SKGObjectModelBase::setData(const QModelIndex& index, const QVariant& value
 
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Update object"), err);
             SKGObjectBase obj2(obj.getDocument(), obj.getRealTable(), obj.getID()); //To be sure this is not a complex object
-            err = obj2.setAttribute(m_listAttibutes[index.column()], value.canConvert<QDateTime>() ? SKGServices::dateToSqlString(value.toDateTime()) : value.toString());
+            QString att = m_listAttibutes[index.column()];
+            err = obj2.setAttribute(att, att.startsWith(QLatin1String("d_")) && value.canConvert<QDateTime>() ? SKGServices::dateToSqlString(value.toDateTime()) : value.toString());
             if (!err) err = obj2.save();
         }
 
