@@ -76,6 +76,13 @@ public:
      */
     virtual bool isRefreshBlocked();
 
+    /**
+     * Returns true if parent has at least one child.
+     * @param parent the parent
+     * @return true or false
+     */
+    virtual bool hasChildren(const QModelIndex& parent = QModelIndex()) const;
+
     /**
      * Returns the number of row for the given parent.
      * @param parent the parent
