@@ -27,7 +27,7 @@
 #include "kicon.h"
 
 SKGShow::SKGShow(QWidget* parent)
-    : QToolButton(parent)
+    : QToolButton(parent), m_mode(OR), m_inTrigger(false)
 {
     setPopupMode(QToolButton::InstantPopup);
     setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
@@ -50,6 +50,16 @@ SKGShow::~SKGShow()
     m_menu = NULL;
 }
 
+SKGShow::OperatorMode SKGShow::getMode()
+{
+    return m_mode;
+}
+
+void SKGShow::setMode(SKGShow::OperatorMode iMode)
+{
+    m_mode = iMode;
+}
+
 QString SKGShow::getState()
 {
     QStringList itemsChecked;
@@ -64,7 +74,7 @@ QString SKGShow::getState()
     return SKGServices::stringsToCsv(itemsChecked);
 }
 
-QString SKGShow::getWhereClause()
+QString SKGShow::getWhereClause() const
 {
     QString wc;
     if (m_menu) {
@@ -74,7 +84,7 @@ QString SKGShow::getWhereClause()
         for (int i = 0; i < nb; ++i) {
             QAction* act = actions.at(i);
             if (act && act->isChecked()) {
-                if (!wc.isEmpty()) wc += " OR ";
+                if (!wc.isEmpty()) wc += (m_mode == OR ? " OR " : " AND ");
                 wc += '(' % m_whereclause[act] % ')';
                 noCheck = false;
 
@@ -89,6 +99,23 @@ QString SKGShow::getWhereClause()
     return wc;
 }
 
+QString SKGShow::getTitle() const
+{
+    QString wc;
+    if (m_menu) {
+        QList<QAction*> actions = m_menu->actions();
+        int nb = actions.count();
+        for (int i = 0; i < nb; ++i) {
+            QAction* act = actions.at(i);
+            if (act && act->isChecked()) {
+                if (!wc.isEmpty()) wc += (m_mode == OR ? " + " : " , ");
+                wc += act->toolTip();
+            };
+        }
+    }
+    return wc;
+}
+
 void SKGShow::setDefaultState(const QString& iState)
 {
     m_defaultState = iState;
@@ -107,21 +134,43 @@ void SKGShow::setState(const QString& iState)
             if (act) act->setChecked(itemsChecked.contains(act->data().toString()));
         }
 
+        //Change tooltip
+        setToolTip(getTitle());
+
+        //Emit event
         emit stateChanged();
     }
 }
 
-void SKGShow::addItem(const QString& iIdentifier, const QString& iText, const QString& iIcon,
-                      const QString& iWhereClose,
-                      const QString& iListIdToCheckWhenChecked ,
-                      const QString& iListIdToUncheckWhenChecked ,
-                      const QString& iListIdToCheckWhenUnchecked ,
-                      const QString& iListIdToUncheckWhenUnchecked
-                     )
+void SKGShow::clear()
+{
+    m_check_to_check.clear();
+    m_uncheck_to_check.clear();
+    m_check_to_uncheck.clear();
+    m_uncheck_to_uncheck.clear();
+    m_actions.clear();
+    m_whereclause.clear();
+    m_defaultState.clear();
+    m_menu->clear();
+}
+
+int SKGShow::count()
+{
+    return m_check_to_check.count();
+}
+
+int SKGShow::addItem(const QString& iIdentifier, const QString& iText, const QString& iIcon,
+                     const QString& iWhereClose,
+                     const QString& iListIdToCheckWhenChecked ,
+                     const QString& iListIdToUncheckWhenChecked ,
+                     const QString& iListIdToCheckWhenUnchecked ,
+                     const QString& iListIdToUncheckWhenUnchecked
+                    )
 {
     if (m_menu) {
         QAction* act = m_menu->addAction(iText);
         if (act) {
+            act->setToolTip(iText);
             act->setIcon(KIcon(iIcon));
             act->setData(iIdentifier);
             act->setCheckable(true);
@@ -130,14 +179,38 @@ void SKGShow::addItem(const QString& iIdentifier, const QString& iText, const QS
             m_check_to_uncheck[act] = iListIdToUncheckWhenChecked;
             m_uncheck_to_check[act] = iListIdToCheckWhenUnchecked;
             m_uncheck_to_uncheck[act] = iListIdToUncheckWhenUnchecked;
+            m_actions.push_back(act);
 
             m_whereclause[act] = iWhereClose;
 
-            connect(act, SIGNAL(triggered(bool)), this, SLOT(itemChanged()));
+            connect(act, SIGNAL(toggled(bool)), this, SLOT(trigger()));
         }
 
         show();
+
+        return (m_actions.count() - 1);
     }
+    return -1;
+}
+
+void SKGShow::setListIdToCheckWhenChecked(int iIndex, const QString& iIds)
+{
+    m_check_to_check[m_actions.at(iIndex)] = iIds;
+}
+
+void SKGShow::setListIdToCheckWhenUnchecked(int iIndex, const QString& iIds)
+{
+    m_uncheck_to_check[m_actions.at(iIndex)] = iIds;
+}
+
+void SKGShow::setListIdToUncheckWhenChecked(int iIndex, const QString& iIds)
+{
+    m_check_to_uncheck[m_actions.at(iIndex)] = iIds;
+}
+
+void SKGShow::setListIdToUncheckWhenUnchecked(int iIndex, const QString& iIds)
+{
+    m_uncheck_to_uncheck[m_actions.at(iIndex)] = iIds;
 }
 
 void SKGShow::addSeparator()
@@ -145,10 +218,12 @@ void SKGShow::addSeparator()
     if (m_menu) m_menu->addSeparator();
 }
 
-void SKGShow::itemChanged()
+void SKGShow::trigger()
 {
     QAction* act = qobject_cast<QAction*>(sender());
-    if (act) {
+    if (act && !m_inTrigger) {
+        m_inTrigger = true;
+
         //Apply rules
         if (act->isChecked()) {
             {
@@ -157,7 +232,7 @@ void SKGShow::itemChanged()
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
                     QAction* act2 = getAction(items.at(i));
-                    if (act2) act2->setChecked(true);
+                    if (act2 && act2 != act) act2->setChecked(true);
                 }
             }
 
@@ -167,7 +242,7 @@ void SKGShow::itemChanged()
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
                     QAction* act2 = getAction(items.at(i));
-                    if (act2) act2->setChecked(false);
+                    if (act2 && act2 != act) act2->setChecked(false);
                 }
             }
         } else {
@@ -177,7 +252,7 @@ void SKGShow::itemChanged()
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
                     QAction* act2 = getAction(items.at(i));
-                    if (act2) act2->setChecked(true);
+                    if (act2 && act2 != act) act2->setChecked(true);
                 }
             }
 
@@ -187,17 +262,22 @@ void SKGShow::itemChanged()
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
                     QAction* act2 = getAction(items.at(i));
-                    if (act2) act2->setChecked(false);
+                    if (act2 && act2 != act) act2->setChecked(false);
                 }
             }
         }
 
+        //Change tooltip
+        setToolTip(getTitle());
+
         //Emit event
         m_timer.start(300);
+
+        m_inTrigger = false;
     }
 }
 
-QAction* SKGShow::getAction(const QString& iIdentifier)
+QAction* SKGShow::getAction(const QString& iIdentifier) const
 {
     QAction* output = NULL;
     if (m_menu) {
@@ -212,4 +292,3 @@ QAction* SKGShow::getAction(const QString& iIdentifier)
 }
 
 #include "skgshow.moc"
-
