@@ -42,7 +42,25 @@ class SKGBASEGUI_EXPORT SKGShow : public QToolButton
      */
     Q_PROPERTY(QString state READ getState WRITE setState USER true);
 
+    /**
+     * Mode
+     */
+    Q_PROPERTY(OperatorMode mode READ getMode WRITE setMode);
+
+    /**
+     * This enumerate defines type of operator
+     */
+    Q_ENUMS(OperatorMode);
+
 public:
+
+    /**
+     * This enumerate defines type of operator
+     */
+    enum OperatorMode {AND,   /**< AND*/
+                       OR      /**< OR*/
+                      };
+
     /**
      * Default Constructor
      * @param parent the parent
@@ -66,6 +84,18 @@ public:
      */
     virtual void setState(const QString& iState);
 
+    /**
+     * Get the current mode
+     * @return the mode
+     */
+    virtual OperatorMode getMode();
+
+    /**
+     * Set the current mode
+     * @param iMode the mode
+     */
+    virtual void setMode(OperatorMode iMode);
+
     /**
      * Set the default state
      * @param iState a string containing all activated item identifiers (separated by ;)
@@ -76,7 +106,27 @@ public:
      * Get the current where clause
      * @return a where clause string
      */
-    virtual QString getWhereClause();
+    virtual QString getWhereClause() const;
+
+    /**
+     * Remove all items
+     */
+    virtual void clear();
+
+    /**
+     * @brief Get the number of items
+     *
+     * @return the number of items
+     **/
+    virtual int count();
+
+    /**
+     * @brief Get the action for an identifier
+     *
+     * @param iIdentifier unique identifier of the item
+     * @return the action
+     **/
+    virtual QAction* getAction(const QString& iIdentifier) const;
 
     /**
      * @brief Add an item to the menu
@@ -89,15 +139,47 @@ public:
      * @param iListIdToUncheckWhenChecked list of item identifiers (separated by ;) to uncheck when unchecked Defaults to "".
      * @param iListIdToCheckWhenUnchecked list of item identifiers (separated by ;) to check when checked Defaults to "".
      * @param iListIdToUncheckWhenUnchecked list of item identifiers (separated by ;) to uncheck when unchecked Defaults to "".
-     * @return void
+     * @return the index of the new item
      **/
-    virtual void addItem(const QString& iIdentifier, const QString& iText, const QString& iIcon = "",
-                         const QString& iWhereClose = "",
-                         const QString& iListIdToCheckWhenChecked = "",
-                         const QString& iListIdToUncheckWhenChecked = "",
-                         const QString& iListIdToCheckWhenUnchecked = "",
-                         const QString& iListIdToUncheckWhenUnchecked = ""
-                        );
+    virtual int addItem(const QString& iIdentifier, const QString& iText, const QString& iIcon = "",
+                        const QString& iWhereClose = "",
+                        const QString& iListIdToCheckWhenChecked = "",
+                        const QString& iListIdToUncheckWhenChecked = "",
+                        const QString& iListIdToCheckWhenUnchecked = "",
+                        const QString& iListIdToUncheckWhenUnchecked = ""
+                       );
+
+    /**
+     * @brief Set the list of items to check when iIndex is checked
+     *
+     * @param iIndex index of the item (@see addItem)
+     * @param iIds list of item identifiers (separated by ;)
+     **/
+    virtual void setListIdToCheckWhenChecked(int iIndex, const QString& iIds);
+
+    /**
+     * @brief Set the list of items to uncheck when iIndex is checked
+     *
+     * @param iIndex index of the item (@see addItem)
+     * @param iIds list of item identifiers (separated by ;)
+     **/
+    virtual void setListIdToUncheckWhenChecked(int iIndex, const QString& iIds);
+
+    /**
+     * @brief Set the list of items to check when iIndex is unchecked
+     *
+     * @param iIndex index of the item (@see addItem)
+     * @param iIds list of item identifiers (separated by ;)
+     **/
+    virtual void setListIdToCheckWhenUnchecked(int iIndex, const QString& iIds);
+
+    /**
+     * @brief Set the list of items to uncheck when iIndex is unchecked
+     *
+     * @param iIndex index of the item (@see addItem)
+     * @param iIds list of item identifiers (separated by ;)
+     **/
+    virtual void setListIdToUncheckWhenUnchecked(int iIndex, const QString& iIds);
 
     /**
      * @brief Add a separator
@@ -115,16 +197,23 @@ Q_SIGNALS:
     void stateChanged();
 
 private Q_SLOTS:
-    void itemChanged();
+    /**
+     * @brief trigger
+     **/
+    void trigger();
 
 private:
     Q_DISABLE_COPY(SKGShow);
-    QAction* getAction(const QString& iIdentifier);
+
+    QString getTitle() const;
 
     KMenu* m_menu;
     QTimer m_timer;
     QString m_defaultState;
+    OperatorMode m_mode;
+    bool m_inTrigger;
 
+    QList<QAction*> m_actions;
     QMap<QAction*, QString> m_check_to_check;
     QMap<QAction*, QString> m_uncheck_to_check;
     QMap<QAction*, QString> m_check_to_uncheck;
