@@ -43,6 +43,30 @@ public:
      */
     virtual ~SKGTableWidget();
 
+    /**
+     * Set the horizontal scroll bar stick to the maximum
+     * @param iStick the stick state
+     */
+    virtual void setStickHorizontal(bool iStick);
+
+    /**
+     * Get the horizontal scroll bar stick to the maximum
+     * @return the stick state
+     */
+    virtual bool stickHorizontal() const;
+
+    /**
+     * Set the vertical scroll bar stick to the maximum
+     * @param iStick the stick state
+     */
+    virtual void setStickVertical(bool iStick);
+
+    /**
+     * Get the vertical scroll bar stick to the maximum
+     * @return the stick state
+     */
+    virtual bool stickVertical() const;
+
 Q_SIGNALS:
     /**
      * Selected items must be removed
@@ -58,8 +82,14 @@ protected:
      */
     virtual bool eventFilter(QObject* object, QEvent* event);
 
-private slots:
+private Q_SLOTS:
     void copy();
+    void onActionTriggered();
+    void onRangeChanged();
+
+private:
+    bool stickH;
+    bool stickV;
 };
 
 #endif // SKGTABLEWIDGET_H
