@@ -49,7 +49,6 @@
 #include <qtextcodec.h>
 #include <qpropertyanimation.h>
 
-
 /**
   * Data identifier for value
   */
@@ -447,6 +446,9 @@ QString SKGTableWithGraph::getState()
     root.setAttribute("web", ui.kTextEdit->getState());
     root.setAttribute("show", ui.kShow->getState());
 
+    if (ui.kTable->stickHorizontal()) root.setAttribute("stickH", "Y");
+    if (ui.kTable->stickVertical()) root.setAttribute("stickV", "Y");
+
     return doc.toString();
 }
 
@@ -482,6 +484,8 @@ void SKGTableWithGraph::setState(const QString& iState)
     QString graphicViewState = root.attribute("graphicViewState");
     QString web = root.attribute("web");
     QString show = root.attribute("show");
+    ui.kTable->setStickHorizontal(root.attribute("stickH") == "Y");
+    ui.kTable->setStickVertical(root.attribute("stickV") == "Y");
 
     //Defaut value in case of reset
     if (graphMode.isEmpty()) graphMode = '0';
