@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -33,6 +33,7 @@
 #include <QtGui/QWidget>
 #include <QWebView>
 
+#include <qmath.h>
 #include "math.h"
 
 SKGTabPage::SKGTabPage(SKGDocument* iDocument)
@@ -56,28 +57,6 @@ bool SKGTabPage::close()
     return QWidget::close();
 }
 
-SKGObjectBase::SKGListSKGObjectBase SKGTabPage::getSelectedObjects()
-{
-    SKGObjectBase::SKGListSKGObjectBase selection;
-
-    QWidget* widget = zoomableWidget();
-    SKGTreeView* treeView = qobject_cast<SKGTreeView*>(widget);
-    if(treeView) selection = treeView->getSelectedObjects();
-
-    return selection;
-}
-
-int SKGTabPage::getNbSelectedObjects()
-{
-    int output = 0;
-    QWidget* widget = zoomableWidget();
-    SKGTreeView* treeView = qobject_cast<SKGTreeView*>(widget);
-    if(treeView) output = treeView->getNbSelectedObjects();
-    else output = getSelectedObjects().count();
-
-    return output;
-}
-
 void SKGTabPage::setBookmarkID(const QString& iId)
 {
     m_bookmarkID = iId;
@@ -110,15 +89,15 @@ void SKGTabPage::setNextPages(const QList<SKGTabPage::SKGPageHistoryItem>& iPage
 bool SKGTabPage::isOverwriteNeeded()
 {
     //Is this widget linked to a bookmark ?
-    if(m_bookmarkID.length()) {
+    if (!m_bookmarkID.isEmpty()) {
         //Yes. Is state modified ?
         SKGNodeObject node(getDocument(), SKGServices::stringToInt(m_bookmarkID));
-        if(node.exist()) {
+        if (node.exist()) {
             QStringList data = SKGServices::splitCSVLine(node.getData());
             QString fullname = node.getFullName();
-            if(data.count() > 3) {
+            if (data.count() > 2) {
                 QString currentState = getState().trimmed();
-                QString oldState = data[3].trimmed();
+                QString oldState = data[2].trimmed();
                 currentState.remove('\n');
                 oldState.remove('\n');
                 SKGTRACEL(20) << "oldState      =[" << oldState << ']' << endl;
@@ -130,14 +109,14 @@ bool SKGTabPage::isOverwriteNeeded()
     } else {
         //No. It is a page opened from context or from another page
         QString name = getDefaultStateAttribute();
-        if(!name.isEmpty()) {
+        if (!name.isEmpty()) {
             QString currentState = getState().trimmed();
             QString oldState = getDocument()->getParameter(name);
             currentState.remove('\n');
             oldState.remove('\n');
             SKGTRACEL(20) << "oldState      =[" << oldState << ']' << endl;
             SKGTRACEL(20) << "currentState  =[" << currentState << ']' << endl;
-            SKGTRACEL(20) << "Context diff =" << (currentState != oldState ? "TRUE" : "FALSE") << endl;
+            SKGTRACEL(20) << "Page diff =" << (currentState != oldState ? "TRUE" : "FALSE") << endl;
             return (currentState != oldState);
         }
     }
@@ -147,38 +126,38 @@ bool SKGTabPage::isOverwriteNeeded()
 void SKGTabPage::overwrite(bool iUserConfirmation)
 {
     //Is this widget linked to a bookmark ?
-    if(m_bookmarkID.length()) {
+    if (!m_bookmarkID.isEmpty()) {
         //Yes. Is state modified ?
         SKGNodeObject node(getDocument(), SKGServices::stringToInt(m_bookmarkID));
-        if(node.exist()) {
+        if (node.exist()) {
             QStringList data = SKGServices::splitCSVLine(node.getData());
             QString fullname = node.getFullName();
-            if(data.count() > 3) {
+            if (data.count() > 2) {
                 QString currentState = getState().trimmed();
-                QString oldState = data[3].trimmed();
+                QString oldState = data[2].trimmed();
                 currentState.remove('\n');
                 oldState.remove('\n');
                 SKGTRACEL(20) << "oldState      =[" << oldState << ']' << endl;
                 SKGTRACEL(20) << "currentState  =[" << currentState << ']' << endl;
-                if(currentState != oldState) {
+                if (currentState != oldState) {
                     QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
                     int conf = KMessageBox::Yes;
-                    if(iUserConfirmation && !oldState.isEmpty()) conf = KMessageBox::questionYesNo(this,
+                    if (iUserConfirmation && !oldState.isEmpty()) conf = KMessageBox::questionYesNo(this,
                                 i18nc("Question", "Bookmark '%1' has been modified. Do you want to update it with the current state?", fullname),
                                 i18nc("Question", "Bookmark has been modified"),
                                 KStandardGuiItem::yes(),
                                 KStandardGuiItem::no(),
                                 QString("updateBookmarkOnClose"));
                     QApplication::restoreOverrideCursor();
-                    if(conf == KMessageBox::Yes) {
+                    if (conf == KMessageBox::Yes) {
                         SKGError err;
                         {
-                            SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark update '%1'", fullname), err);
-                            data[3] = currentState;
-                            if(err.isSucceeded()) err = node.setData(SKGServices::stringsToCsv(data));
-                            if(err.isSucceeded()) err = node.save();
+                            SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark update '%1'", fullname), err);
+                            data[2] = currentState;
+                            if (!err) err = node.setData(SKGServices::stringsToCsv(data));
+                            if (!err) err = node.save();
                         }
-                        if(err.isSucceeded()) err = SKGError(0, i18nc("Successful message after an user action", "Bookmark updated"));
+                        if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Bookmark updated"));
                         SKGMainPanel::displayErrorMessage(err);
                     }
                 }
@@ -187,30 +166,30 @@ void SKGTabPage::overwrite(bool iUserConfirmation)
     } else {
         //No. It is a page opened from context or from another page
         QString name = getDefaultStateAttribute();
-        if(!name.isEmpty()) {
+        if (!name.isEmpty()) {
             QString currentState = getState().trimmed();
             QString oldState = getDocument()->getParameter(name);
             SKGTRACEL(20) << "oldState      =[" << oldState << ']' << endl;
             SKGTRACEL(20) << "currentState  =[" << currentState << ']' << endl;
             currentState.remove('\n');
             oldState.remove('\n');
-            if(currentState != oldState) {
+            if (currentState != oldState) {
                 QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
                 int conf = KMessageBox::Yes;
-                if(iUserConfirmation && !oldState.isEmpty()) conf = KMessageBox::questionYesNo(this,
+                if (iUserConfirmation && !oldState.isEmpty()) conf = KMessageBox::questionYesNo(this,
                             i18nc("Question", "Page has been modified. Do you want to update it with the current state?"),
                             i18nc("Question", "Page has been modified"),
                             KStandardGuiItem::yes(),
                             KStandardGuiItem::no(),
                             QString("updateContextOnClose"));
                 QApplication::restoreOverrideCursor();
-                if(conf == KMessageBox::Yes) {
+                if (conf == KMessageBox::Yes) {
                     SKGError err;
                     {
-                        SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Save default state"), err);
+                        SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Save default state"), err);
                         err = getDocument()->setParameter(name, currentState);
                     }
-                    if(err.isSucceeded()) err = SKGError(0, i18nc("Successful message after an user action", "Default state saved"));
+                    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Default state saved"));
                     SKGMainPanel::displayErrorMessage(err);
                 }
             }
@@ -226,16 +205,18 @@ bool SKGTabPage::isEditor()
 
 void SKGTabPage::activateEditor() {}
 
-QWidget* SKGTabPage::mainWidget() const
-{
-    return (QWidget*) this;
-}
-
 QWidget* SKGTabPage::zoomableWidget() const
 {
     return mainWidget();
 }
 
+QList< QWidget* > SKGTabPage::printableWidgets() const
+{
+    QList< QWidget* > output;
+    output.push_back(mainWidget());
+    return output;
+}
+
 bool SKGTabPage::isZoomable() const
 {
     return (zoomableWidget() != NULL);
@@ -245,12 +226,12 @@ void SKGTabPage::setZoomPosition(int iValue)
 {
     QWidget* widget = zoomableWidget();
     SKGTreeView* treeView = qobject_cast<SKGTreeView*>(widget);
-    if(treeView) treeView->setZoomPosition(iValue);
+    if (treeView) treeView->setZoomPosition(iValue);
     else {
         QWebView* webView = qobject_cast<QWebView*>(widget);
-        if(webView) {
-            webView->setZoomFactor(pow(10, ((qreal) iValue) / 30.0));
-        } else if(widget) {
+        if (webView) {
+            webView->setZoomFactor(qPow(10, ((qreal) iValue) / 30.0));
+        } else if (widget) {
             QFont font = widget->font();
             font.setPointSize(qMax(1, m_fontOriginalPointSize + iValue));
             widget->setFont(font);
@@ -262,13 +243,24 @@ int SKGTabPage::zoomPosition() const
 {
     QWidget* widget = zoomableWidget();
     SKGTreeView* treeView = qobject_cast<SKGTreeView*>(widget);
-    if(treeView) return treeView->zoomPosition();
+    if (treeView) return treeView->zoomPosition();
     else {
         QWebView* webView = qobject_cast<QWebView*>(widget);
-        if(webView) return round(30.0 * log10(webView->zoomFactor()));
-        else if(widget) return widget->font().pointSize() - m_fontOriginalPointSize;
+        if (webView) return qRound(30.0 * log10(webView->zoomFactor()));
+        else if (widget) return widget->font().pointSize() - m_fontOriginalPointSize;
     }
     return 0;
 }
 
+SKGTabPage* SKGTabPage::parentTabPage(QWidget* iWidget)
+{
+    SKGTabPage* output = qobject_cast< SKGTabPage* >(iWidget);
+    if (!output && iWidget) {
+        QWidget* parent = iWidget->parentWidget();
+        if (parent)  output = SKGTabPage::parentTabPage(parent);
+    }
+
+    return output;
+}
+
 #include "skgtabpage.moc"
