@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -30,17 +30,16 @@
 
 #include <QHBoxLayout>
 #include <QPushButton>
-#include <QTabBar>
 #include <QTimer>
 #include <QStringList>
 
-SKGTabWidget::SKGTabWidget(QWidget *parent)
+SKGTabWidget::SKGTabWidget(QWidget* parent)
     : KTabWidget(parent)
 {
     m_timerSave.setSingleShot(true);
     connect(&m_timerSave, SIGNAL(timeout()), this, SLOT(onRefreshSaveIcon()), Qt::QueuedConnection);
-    connect(tabBar(), SIGNAL(moveTab(int, int)), this, SLOT(onMoveTab(int, int)));
-    connect(static_cast<SKGMainPanel*>(parent), SIGNAL(currentPageChanged()), this, SLOT(onCurrentChanged()));
+    connect(tabBar(), SIGNAL(moveTab(int,int)), this, SLOT(onMoveTab(int,int)));
+    if (parent) connect(static_cast<SKGMainPanel*>(parent), SIGNAL(currentPageChanged()), this, SLOT(onCurrentChanged()));
 
     // Use new KDE for moving tabs.
     KTabBar* tabbar = qobject_cast< KTabBar* >(tabBar());
@@ -55,7 +54,7 @@ SKGTabWidget::~SKGTabWidget()
 
 void SKGTabWidget::onCurrentChanged()
 {
-    if(currentWidget() && !m_tabIndexSaveButton.keys().contains(currentWidget())) {
+    if (currentWidget() && !m_tabIndexSaveButton.keys().contains(currentWidget())) {
         //Build widgets
         QPushButton* kSave = new QPushButton(this);
         kSave->setIcon(KIcon("document-save"));
@@ -65,7 +64,7 @@ void SKGTabWidget::onCurrentChanged()
         kSave->show();
 
         connect(kSave, SIGNAL(clicked()), this, SLOT(onSaveRequested()));
-        tabBar()->setTabButton(currentIndex(), QTabBar::LeftSide, kSave);
+        tabBar()->setTabButton(currentIndex(), KTabBar::LeftSide, kSave);
 
         m_tabIndexSaveButton.insert(currentWidget(), kSave);
     }
@@ -74,14 +73,14 @@ void SKGTabWidget::onCurrentChanged()
     QMap<QWidget*, QPushButton*> TabIndexSaveButton2;
 
     int nb = count();
-    for(int i = 0; i < nb; ++i) {
+    for (int i = 0; i < nb; ++i) {
         QWidget* w = widget(i);
         QPushButton* save = static_cast<QPushButton*>(m_tabIndexSaveButton[w]);
-        if(w && save) {
+        if (w && save) {
             save->setVisible(false);
 
             QPushButton* s = m_tabIndexSaveButton.value(w);
-            if(s != NULL) TabIndexSaveButton2[w] = s;
+            if (s != NULL) TabIndexSaveButton2[w] = s;
         }
     }
 
@@ -107,8 +106,8 @@ void SKGTabWidget::onMoveTab(int oldPos, int newPos)
 
 void SKGTabWidget::onSaveRequested()
 {
-    SKGTabPage *page = qobject_cast<SKGTabPage*>(currentWidget());
-    if(page) {
+    SKGTabPage* page = qobject_cast<SKGTabPage*>(currentWidget());
+    if (page) {
         page->overwrite(false);
         onRefreshSaveIcon();
     }
@@ -116,13 +115,13 @@ void SKGTabWidget::onSaveRequested()
 
 void SKGTabWidget::onRefreshSaveIcon()
 {
-    SKGTabPage *page = qobject_cast<SKGTabPage*>(currentWidget());
-    if(page) {
+    SKGTabPage* page = qobject_cast<SKGTabPage*>(currentWidget());
+    if (page) {
         QPushButton* save = qobject_cast<QPushButton*>(m_tabIndexSaveButton[page]);
-        if(save) {
-            if(page->isOverwriteNeeded()) {
+        if (save) {
+            if (page->isOverwriteNeeded()) {
                 save->show();
-                if(page->getBookmarkID().isEmpty()) {
+                if (page->getBookmarkID().isEmpty()) {
                     save->setIcon(KIcon("document-save"));
                 } else {
                     QStringList overlay;
