@@ -58,7 +58,8 @@ SKGTreeView::SKGTreeView(QWidget* parent)
     : QTreeView(parent),
       m_autoResize(true), m_actAutoResize(NULL),
       m_document(NULL), m_textResizable(true),
-      m_model(NULL), m_proxyModel(NULL)
+      m_model(NULL), m_proxyModel(NULL),
+      stickH(false), stickV(false)
 {
     //Initialize
     setTextElideMode(Qt::ElideMiddle);
@@ -85,19 +86,24 @@ SKGTreeView::SKGTreeView(QWidget* parent)
 
     //
     KAction* actCopy = KStandardAction::copy(this, SLOT(copy()), NULL);
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_copy", actCopy);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_copy", actCopy);
     insertGlobalAction("edit_copy");
 
     m_actExpandAll = new KAction(KIcon("format-indent-more"), i18nc("Noun, user action", "Expand all"), this);
     connect(m_actExpandAll, SIGNAL(triggered(bool)), this, SLOT(expandAll()));
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_expandall", m_actExpandAll);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_expandall", m_actExpandAll);
     insertGlobalAction("edit_expandall");
 
     m_actCollapseAll = new KAction(KIcon("format-indent-less"), i18nc("Noun, user action", "Collapse all"), this);
     connect(m_actCollapseAll, SIGNAL(triggered(bool)), this, SLOT(collapseAll()));
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_collapseal", m_actCollapseAll);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_collapseal", m_actCollapseAll);
     insertGlobalAction("edit_collapseal");
 
+    connect(horizontalScrollBar(), SIGNAL(actionTriggered(int)), this, SLOT(onActionTriggered(int)));
+    connect(verticalScrollBar(), SIGNAL(actionTriggered(int)), this, SLOT(onActionTriggered(int)));
+    connect(horizontalScrollBar(), SIGNAL(rangeChanged(int,int)), this, SLOT(onRangeChanged()));
+    connect(verticalScrollBar(), SIGNAL(rangeChanged(int,int)), this, SLOT(onRangeChanged()));
+
     //Headers
     hori->setMovable(true);
     hori->setResizeMode(QHeaderView::Fixed);
@@ -177,9 +183,19 @@ QString SKGTreeView::getState()
             root.setAttribute("columnsVisibility", columnsVisibility);
             root.setAttribute("columnsAutoResize", m_autoResize ? "Y" : "N");
         }
+
+        //Memorize expanded groups
+        if (!m_groupby.isEmpty()) {
+            root.setAttribute("expandedGroups", SKGServices::stringsToCsv(m_expandedNodes));
+        }
     }
     root.setAttribute("alternatingRowColors", alternatingRowColors() ? "Y" : "N");
     root.setAttribute("zoomPosition", SKGServices::intToString(zoomPosition()));
+
+    QScrollBar* scroll = horizontalScrollBar();
+    if (scroll && scroll->value() == scroll->maximum() && scroll->value() != scroll->minimum()) root.setAttribute("stickH", "Y");
+    scroll = verticalScrollBar();
+    if (scroll && scroll->value() == scroll->maximum() && scroll->value() != scroll->minimum()) root.setAttribute("stickV", "Y");
     return doc.toString();
 }
 
@@ -209,6 +225,9 @@ void SKGTreeView::setState(const QString& iState)
         QString columnsAutoResize = root.attribute("columnsAutoResize");
         QString alternatingRowColors = root.attribute("alternatingRowColors");
         QString zoomPosition = root.attribute("zoomPosition");
+        QString expandedGroups = root.attribute("expandedGroups");
+        stickH = (root.attribute("stickH") == "Y");
+        stickV = (root.attribute("stickV") == "Y");
 
         //Set column order
         QStringList listAtt;
@@ -264,6 +283,10 @@ void SKGTreeView::setState(const QString& iState)
         //Set alternatingRowColors
         if (!alternatingRowColors.isEmpty()) setAlternatingRowColors(alternatingRowColors == "Y");
         if (!zoomPosition.isEmpty()) setZoomPosition(SKGServices::stringToInt(zoomPosition));
+
+        //Set expanded groups
+        m_expandedNodes = SKGServices::splitCSVLine(expandedGroups);
+        resetSelection();
     } else {
         if (m_model) {
             m_model->setSupportedAttributes(QStringList());
@@ -279,9 +302,26 @@ void SKGTreeView::setState(const QString& iState)
 
         this->sortByColumn(0, qtsortorder);
     }
+}
 
-    if (qtsortorder == Qt::AscendingOrder) scrollToBottom();
-    else scrollToTop();
+void SKGTreeView::onRangeChanged()
+{
+    QScrollBar* scroll = qobject_cast<QScrollBar*>(sender());
+    if ((stickH && scroll == horizontalScrollBar()) || (stickV && scroll == verticalScrollBar())) {
+        scroll->setValue(scroll->maximum());
+    }
+}
+
+void SKGTreeView::onActionTriggered(int action)
+{
+    QScrollBar* scroll = qobject_cast<QScrollBar*>(sender());
+    if (scroll && action == QAbstractSlider::SliderToMaximum) {
+        if (scroll == horizontalScrollBar()) stickH = true;
+        if (scroll == verticalScrollBar()) stickV = true;
+    } else {
+        if (scroll == horizontalScrollBar()) stickH = false;
+        if (scroll == verticalScrollBar()) stickV = false;
+    }
 }
 
 void SKGTreeView::insertGlobalAction(const QString& iRegisteredAction)
