@@ -126,7 +126,7 @@ public:
 
     /**
      * Insert a registered action
-     * @see SKGMainPanel::registedGlobalAction
+     * @see SKGMainPanel::registerGlobalAction
      * @param iRegisteredAction the registered action. "" means separator
      */
     virtual void insertGlobalAction(const QString& iRegisteredAction = "");
@@ -275,6 +275,8 @@ private Q_SLOTS:
     void onCollapse(const QModelIndex& index);
     void onClick(const QModelIndex& index);
     void copy();
+    void onActionTriggered(int action);
+    void onRangeChanged();
 
 private:
     Q_DISABLE_COPY(SKGTreeView);
@@ -302,6 +304,9 @@ private:
     QSortFilterProxyModel* m_proxyModel;
 
     SKGObjectBase::SKGListSKGObjectBase m_lastSelection;
+
+    bool stickH;
+    bool stickV;
 };
 
 #endif // SKGTREEVIEW_H
