@@ -335,6 +335,11 @@ public Q_SLOTS:
      */
     virtual bool isFileModified() const;
 
+    /**
+     * Set the file not modified.
+     */
+    virtual void setFileNotModified();
+
     /**
      * To know if the document is loaded in read only.
      * @return true: the document is loaded in read only.
@@ -753,6 +758,14 @@ Q_SIGNALS:
     void objectRemoved(const SKGObjectBase& iObject);
 
 protected:
+    /**
+     * Drop views and indexes attached to a list of tables
+     * @param iTables the list of tables.
+     * @return an object managing the error.
+     *   @see SKGError
+     */
+    virtual SKGError dropViewsAndIndexes(const QStringList& iTables) const;
+
     /**
      * Migrate the current SKGDocument to the latest version of the data model.
      * WARNING: This method must be used in a transaction.
