@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,6 +21,36 @@
 */
 #include "skgerror.h"
 
+QDBusArgument& operator<<(QDBusArgument& iArgument, const SKGError& iError)
+{
+    iArgument.beginStructure();
+    iArgument << iError.getReturnCode() << iError.getMessage();
+    iArgument.endStructure();
+    return iArgument;
+}
+const QDBusArgument& operator>>(const QDBusArgument& iArgument, SKGError& iError)
+{
+    iArgument.beginStructure();
+    int rc = 0;
+    iArgument >> rc;
+    iError.setReturnCode(rc);
+    QString message;
+    iArgument >> message;
+    iError.setMessage(message);
+    iArgument.endStructure();
+    return iArgument;
+}
+
+QScriptValue SKGErrorToScriptValue(QScriptEngine* engine, SKGError* const& in)
+{
+    return engine->newQObject(in);
+}
+
+void SKGErrorFromScriptValue(const QScriptValue& object, SKGError* &out)
+{
+    out = qobject_cast<SKGError*>(object.toQObject());
+}
+
 SKGError::SKGError()
     : QObject(), m_rc(0), m_message(""), m_previousError(NULL)
 {}
@@ -34,33 +64,39 @@ SKGError::SKGError(const SKGError& iError)
 {
     m_rc = iError.m_rc;
     m_message = iError.m_message;
-    if(iError.m_previousError != NULL) m_previousError = new SKGError(*iError.m_previousError);
+    if (iError.m_previousError != NULL) m_previousError = new SKGError(*iError.m_previousError);
     else m_previousError = NULL;
 }
 
 SKGError::~SKGError()
 {
-    if(m_previousError) {
-        delete m_previousError;
-        m_previousError = NULL;
-    }
+    delete m_previousError;
+    m_previousError = NULL;
 }
 
-const SKGError& SKGError::operator= (const SKGError & iError)
+const SKGError& SKGError::operator= (const SKGError& iError)
 {
-    if(&iError != this) {
-        if(m_previousError) {
-            delete m_previousError;
-            m_previousError = NULL;
-        }
+    if (&iError != this) {
+        delete m_previousError;
+        m_previousError = NULL;
 
         m_rc = iError.m_rc;
         m_message = iError.m_message;
-        if(iError.m_previousError != NULL) m_previousError = new SKGError(*iError.m_previousError);
+        if (iError.m_previousError != NULL) m_previousError = new SKGError(*iError.m_previousError);
     }
     return *this;
 }
 
+bool SKGError::operator!() const
+{
+    return isSucceeded();
+}
+
+SKGError::operator bool() const
+{
+    return isFailed();
+}
+
 bool SKGError::isFailed() const
 {
     return (m_rc > 0);
@@ -86,7 +122,7 @@ void SKGError::setReturnCode(int iReturnCode)
     m_rc = iReturnCode;
 }
 
-void SKGError::setMessage(const QString & iMessage)
+void SKGError::setMessage(const QString& iMessage)
 {
     m_message = iMessage;
 }
@@ -106,30 +142,30 @@ QString SKGError::getFullMessage() const
     tmp.setNum(m_rc);
     output += tmp;
     output += ']';
-    if(m_message.length()) output += ": " + m_message;
+    if (!m_message.isEmpty()) output += ": " % m_message;
     return output;
 }
 
 QString SKGError::getFullMessageWithHistorical() const
 {
     QString output = getFullMessage();
-    if(m_previousError) output += '\n' + m_previousError->getFullMessageWithHistorical();
+    if (m_previousError) output += '\n' % m_previousError->getFullMessageWithHistorical();
     return output;
 }
 
 int SKGError::getHistoricalSize() const
 {
     int output = 0;
-    if(m_previousError) output += 1 + m_previousError->getHistoricalSize();
+    if (m_previousError) output += 1 + m_previousError->getHistoricalSize();
     return output;
 }
 
-void SKGError::addError(int iRc, const QString & iMessage)
+void SKGError::addError(int iRc, const QString& iMessage)
 {
     SKGError* pe = new SKGError(*this);
     setReturnCode(iRc);
     setMessage(iMessage);
-    if(m_previousError) delete m_previousError;
+    delete m_previousError;
     m_previousError = pe;
 }
 
