@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -26,6 +26,9 @@
 
 #include <QString>
 #include <QObject>
+#include <QDBusArgument>
+#include <qscriptvalue.h>
+#include <qscriptengine.h>
 /**
 * This class manages errors
 */
@@ -70,7 +73,7 @@ public:
     * @param iRc the error code
     * @param iMessage the error message
     */
-    SKGError(int iRc, const QString & iMessage);
+    SKGError(int iRc, const QString& iMessage);
 
     /**
     * Destructor
@@ -81,8 +84,21 @@ public:
     * Operator affectation
     * @param iError the error to copy
     */
-    const SKGError& operator= (const SKGError &iError);
+    const SKGError& operator= (const SKGError& iError);
 
+    /**
+    * To know if this is an error or not. Equivalent to @see isSucceeded
+    * @return true or false
+    */
+    virtual bool operator!() const;
+
+    /**
+    * To know if this is an error or not. Equivalent to @see isFailed
+    * @return true or false
+    */
+    virtual operator bool() const;
+
+public slots:
     /**
     * To know if it's an error or not
     * @return true: It's an error
@@ -125,7 +141,7 @@ public:
     * Set the message associated to this error
     * @param iMessage the message
     */
-    virtual void setMessage(const QString &  iMessage);
+    virtual void setMessage(const QString&   iMessage);
 
     /**
     * Return the message associated to this error
@@ -156,7 +172,7 @@ public:
     * @param iRc the error code
     * @param iMessage the error message
     */
-    virtual void addError(int iRc, const QString & iMessage);
+    virtual void addError(int iRc, const QString& iMessage);
 
     /**
     * Add a new historical message to the current error.
@@ -194,4 +210,44 @@ private:
  * Declare the class
  */
 Q_DECLARE_TYPEINFO(SKGError, Q_MOVABLE_TYPE);
+
+/**
+ * Declare the meta type
+ */
+Q_DECLARE_METATYPE(SKGError);
+
+/**
+ * Declare the meta type
+ */
+Q_DECLARE_METATYPE(SKGError*);
+
+/**
+* Function for scription
+* @param engine the engine
+* @param in the object
+* @return the value
+*/
+SKGBASEMODELER_EXPORT QScriptValue SKGErrorToScriptValue(QScriptEngine* engine, SKGError* const& in);
+
+/**
+* Function for scription
+* @param object the object
+* @param out the object
+*/
+SKGBASEMODELER_EXPORT void SKGErrorFromScriptValue(const QScriptValue& object, SKGError* &out);
+
+/**
+* Operator <<
+* @param iArgument the DBus argument
+* @param iError the error
+*/
+SKGBASEMODELER_EXPORT QDBusArgument& operator<<(QDBusArgument& iArgument, const SKGError& iError);
+
+/**
+* Operator >>
+* @param iArgument the DBus argument
+* @param iError the error
+*/
+SKGBASEMODELER_EXPORT const QDBusArgument& operator>>(const QDBusArgument& iArgument, SKGError& iError);
+
 #endif //SKGERROR_H
