@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -44,7 +44,7 @@ SKGNodeObject::SKGNodeObject(const SKGObjectBase& iObject)
 {
 }
 
-const SKGNodeObject& SKGNodeObject::operator= (const SKGObjectBase & iObject)
+const SKGNodeObject& SKGNodeObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -53,7 +53,7 @@ const SKGNodeObject& SKGNodeObject::operator= (const SKGObjectBase & iObject)
 SKGError SKGNodeObject::setName(const QString& iName)
 {
     SKGError err;
-    if(iName.contains(OBJECTSEPARATOR)) err = SKGError(ERR_FAIL, i18nc("Error message: an invalid character was found", "The name '%1' is invalid : the '%2' character is forbidden ", iName, QString(OBJECTSEPARATOR)));
+    if (iName.contains(OBJECTSEPARATOR)) err = SKGError(ERR_FAIL, i18nc("Error message: an invalid character was found", "The name '%1' is invalid : the '%2' character is forbidden ", iName, QString(OBJECTSEPARATOR)));
     else err = SKGNamedObject::setName(iName);
     return err;
 }
@@ -62,14 +62,14 @@ QString SKGNodeObject::getWhereclauseId() const
 {
     //Could we use the id
     QString output = SKGObjectBase::getWhereclauseId();
-    if(output.isEmpty()) {
-        if(!(getAttribute("t_name").isEmpty())) {
-            output = "t_name='" + SKGServices::stringToSqlString(getAttribute("t_name")) + '\'';
+    if (output.isEmpty()) {
+        if (!(getAttribute("t_name").isEmpty())) {
+            output = "t_name='" % SKGServices::stringToSqlString(getAttribute("t_name")) % '\'';
         }
-        QString r_node_id = getAttribute("r_node_id");
-        if(!output.isEmpty()) output += " AND ";
-        if(r_node_id.isEmpty()) output += "(r_node_id=0 OR r_node_id IS NULL OR r_node_id='')";
-        else output += "r_node_id=" + r_node_id;
+        QString rd_node_id = getAttribute("rd_node_id");
+        if (!output.isEmpty()) output += " AND ";
+        if (rd_node_id.isEmpty()) output += "(rd_node_id=0 OR rd_node_id IS NULL OR rd_node_id='')";
+        else output += "rd_node_id=" % rd_node_id;
     }
     return output;
 }
@@ -91,22 +91,19 @@ QString SKGNodeObject::getData() const
 
 bool SKGNodeObject::isFolder() const
 {
-    return (SKGServices::splitCSVLine(getData()).count() <= 2);
+    return getData().isEmpty();
+}
+
+SKGError SKGNodeObject::setIcon(const QString& iIcon)
+{
+    return setAttribute("t_icon", iIcon);
 }
 
 QIcon SKGNodeObject::getIcon() const
 {
-    QStringList data = SKGServices::splitCSVLine(getData());
-    QIcon icon = KIcon("folder");
-    if(data.count() > 2)  icon = (QIcon) KIcon(data.at(2));
-
-    if(isAutoStart()) {
-        //Modify icon
-        QStringList overlay;
-        overlay.push_back("user-online");
-        if(data.count() > 2)  icon = (QIcon) KIcon(data.at(2), NULL, overlay);
-        else icon = (QIcon) KIcon("folder", NULL, overlay);
-    }
+    QStringList overlay;
+    if (isAutoStart()) overlay.push_back("user-online");
+    QIcon icon = (QIcon) KIcon(getAttribute("t_icon"), NULL, overlay);
     return icon;
 }
 
@@ -124,13 +121,13 @@ SKGError SKGNodeObject::setOrder(double iOrder)
 {
     SKGError err;
     double order = iOrder;
-    if(order == -1) {
+    if (order == -1) {
         order = 1;
         SKGStringListList result;
         err = getDocument()->executeSelectSqliteOrder("SELECT max(f_sortorder) from node", result);
-        if(err.isSucceeded() && result.count() == 2) order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
+        if (!err && result.count() == 2) order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
     }
-    if(err.isSucceeded()) err = setAttribute("f_sortorder", SKGServices::doubleToString(order));
+    if (!err) err = setAttribute("f_sortorder", SKGServices::doubleToString(order));
     return err;
 }
 
@@ -148,26 +145,27 @@ SKGError SKGNodeObject::createPathNode(SKGDocument* iDocument,
     SKGTRACEINRC(10, "SKGNodeObject::createPathNode", err);
     SKGTRACEL(10) << "Input parameter [iFullPath]=" << iFullPath << endl;
     //Check if node is already existing
-    if(!iRenameIfAlreadyExist && iDocument) iDocument->getObject("v_node", "t_fullname='" + SKGServices::stringToSqlString(iFullPath) + '\'', oNode);
-    if(oNode.getID() == 0) {
+    if (!iRenameIfAlreadyExist && iDocument) iDocument->getObject("v_node", "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % '\'', oNode);
+    if (oNode.getID() == 0) {
         //No, we have to create it
         //Search node separator
         int posSeparator = iFullPath.lastIndexOf(OBJECTSEPARATOR);
-        if(posSeparator == -1) {
+        if (posSeparator == -1) {
             oNode = SKGNodeObject(iDocument);
             err = oNode.setName(iFullPath);
 
             //Check if already existing
-            if(err.isSucceeded() && iRenameIfAlreadyExist) {
+            if (!err && iRenameIfAlreadyExist) {
                 int index = 1;
-                while(err.isSucceeded() && oNode.exist()) {
+                while (!err && oNode.exist()) {
                     index++;
-                    err = oNode.setName(iFullPath + " (" + SKGServices::intToString(index) + ')');
+                    err = oNode.setName(iFullPath % " (" % SKGServices::intToString(index) % ')');
                 }
             }
 
-            if(err.isSucceeded()) err = oNode.setOrder(-1);
-            if(err.isSucceeded()) err = oNode.save();
+            if (!err) err = oNode.setIcon("folder");
+            if (!err) err = oNode.setOrder(-1);
+            if (!err) err = oNode.save();
         } else {
             //Get first and second parts of the branch
             QString first = iFullPath.mid(0, posSeparator);
@@ -177,25 +175,26 @@ SKGError SKGNodeObject::createPathNode(SKGDocument* iDocument,
             SKGNodeObject FirstNode;
             err = SKGNodeObject::createPathNode(iDocument, first, FirstNode);
 
-            if(err.isSucceeded()) {
+            if (!err) {
                 //Get second node
                 err = FirstNode.addNode(oNode);
 
                 //Add second under first
-                if(err.isSucceeded()) err = oNode.setName(second);
+                if (!err) err = oNode.setName(second);
 
                 //Check if already existing
-                if(err.isSucceeded() && iRenameIfAlreadyExist) {
+                if (!err && iRenameIfAlreadyExist) {
                     int index = 2;
-                    while(err.isSucceeded() && oNode.exist()) {
-                        err = oNode.setName(second + " (" + SKGServices::intToString(index) + ')');
+                    while (!err && oNode.exist()) {
+                        err = oNode.setName(second % " (" % SKGServices::intToString(index) % ')');
                         ++index;
                     }
                 }
 
                 //save
-                if(err.isSucceeded()) err = oNode.setOrder(-1);
-                if(err.isSucceeded()) err = oNode.save();
+                if (!err) err = oNode.setIcon("folder");
+                if (!err) err = oNode.setOrder(-1);
+                if (!err) err = oNode.save();
             }
         }
     }
@@ -207,38 +206,38 @@ SKGError SKGNodeObject::addNode(SKGNodeObject& oNode)
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGNodeObject::addNode", err);
-    if(getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message: Something failed because of a database issue", "%1 failed because linked object is not yet saved in the database.", QString("SKGNodeObject::addNode")));
+    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message: Something failed because of a database issue", "%1 failed because linked object is not yet saved in the database.", QString("SKGNodeObject::addNode")));
     else {
         oNode = SKGNodeObject(getDocument());
-        err = oNode.setAttribute("r_node_id", SKGServices::intToString(getID()));
+        err = oNode.setAttribute("rd_node_id", SKGServices::intToString(getID()));
     }
     return err;
 }
 
 SKGError SKGNodeObject::removeParentNode()
 {
-    return setAttribute("r_node_id", "");
+    return setAttribute("rd_node_id", "");
 }
 
 SKGError SKGNodeObject::setParentNode(const SKGNodeObject& iNode)
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGNodeObject::setParentNode", err);
-    if(iNode.getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message: Something failed because of a database issue", "%1 failed because linked object is not yet saved in the database.", QString("SKGNodeObject::setParentNode")));
+    if (iNode.getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message: Something failed because of a database issue", "%1 failed because linked object is not yet saved in the database.", QString("SKGNodeObject::setParentNode")));
     else {
         //Check if it's a loop
         SKGNodeObject current = iNode;
         do {
-            if(current == *this) {
+            if (current == *this) {
                 err = SKGError(ERR_FAIL, i18nc("Error message: Loops are forbidden in Skrooge data structures", "You cannot create a loop, ie parent and child with the same name. For example, A > A is a loop. A > B > A is another kind of loop"));
             } else {
                 SKGNodeObject parent;
                 current.getParentNode(parent);
                 current = parent;
             }
-        } while(err.isSucceeded() && current.getID() != 0);
+        } while (!err && current.getID() != 0);
 
-        if(err.isSucceeded()) err = setAttribute("r_node_id", SKGServices::intToString(iNode.getID()));
+        if (!err) err = setAttribute("rd_node_id", SKGServices::intToString(iNode.getID()));
     }
     return err;
 }
@@ -246,14 +245,14 @@ SKGError SKGNodeObject::setParentNode(const SKGNodeObject& iNode)
 SKGError SKGNodeObject::getParentNode(SKGNodeObject& oNode) const
 {
     SKGError err;
-    QString parent_id = getAttribute("r_node_id");
-    if(!parent_id.isEmpty()) err = getDocument()->getObject("v_node", "id=" + parent_id , oNode);
+    QString parent_id = getAttribute("rd_node_id");
+    if (!parent_id.isEmpty()) err = getDocument()->getObject("v_node", "id=" % parent_id , oNode);
     return err;
 }
 
 SKGError SKGNodeObject::getNodes(SKGListSKGObjectBase& oNodeList) const
 {
-    return getDocument()->getObjects("v_node", "r_node_id=" + SKGServices::intToString(getID()) + " ORDER BY f_sortorder, t_name", oNodeList);
+    return getDocument()->getObjects("v_node", "rd_node_id=" % SKGServices::intToString(getID()) % " ORDER BY f_sortorder, t_name", oNodeList);
 }
 
 #include "skgnodeobject.moc"
