@@ -1045,7 +1045,7 @@ double SKGServices::getMicroTime()
 #endif
 }
 
-SKGStringListList SKGServices::getPercentTable(const SKGStringListList& iTable)
+SKGStringListList SKGServices::getPercentTable(const SKGStringListList& iTable, bool iOfColumns, bool iAbsolute)
 {
     SKGTRACEIN(10, "SKGServices::getPercentTable");
 
@@ -1063,15 +1063,32 @@ SKGStringListList SKGServices::getPercentTable(const SKGStringListList& iTable)
 
     //Compute sums
     QList<double> sums;
-    for (int j = 1; j < nbCols; ++j) {
+    if (iOfColumns) {
+        //Compute sum of columns
+        for (int j = 1; j < nbCols; ++j) {
 
-        //Compute sum
-        double sum = 0;
-        for (int i = 1; i < nblines; ++i) {
-            sum += SKGServices::stringToDouble(iTable.at(i).at(j));
+            //Compute sum
+            double sum = 0;
+            for (int i = 1; i < nblines; ++i) {
+                double v = SKGServices::stringToDouble(iTable.at(i).at(j));
+                sum += (iAbsolute ? qAbs(v) : v);
+            }
+
+            sums.push_back(sum);
         }
+    } else {
+        //Compute sum of lines
+        for (int j = 1; j < nblines; ++j) {
 
-        sums.push_back(sum);
+            //Compute sum
+            double sum = 0;
+            for (int i = 1; i < nbCols; ++i) {
+                double v = SKGServices::stringToDouble(iTable.at(j).at(i));
+                sum += (iAbsolute ? qAbs(v) : v);
+            }
+
+            sums.push_back(sum);
+        }
     }
 
     //Create table
@@ -1081,7 +1098,8 @@ SKGStringListList SKGServices::getPercentTable(const SKGStringListList& iTable)
 
         for (int j = 1; j < nbCols; ++j) {
             double val = SKGServices::stringToDouble(iTable.at(i).at(j));
-            double sum = sums.at(j - 1);
+            val = (iAbsolute ? qAbs(val) : val);
+            double sum = (iOfColumns ? sums.at(j - 1) : sums.at(i - 1));
             newLine.push_back(SKGServices::doubleToString(sum == 0.0 ? 0.0 : 100.0 * val / sum));
         }
         output.push_back(newLine);
