@@ -444,8 +444,11 @@ public:
     /**
      * Create a table with all values expressed in % of the column
      * @param iTable table
+     * @param iOfColumns false to compute percentage of lines, true to compute perceentage of columns
+     * @param iAbsolute transform all values in absolute
+     * @return the table
      */
-    static SKGStringListList getPercentTable(const SKGStringListList& iTable);
+    static SKGStringListList getPercentTable(const SKGStringListList& iTable, bool iOfColumns = true, bool iAbsolute = false);
 
     /**
      * Create an historized table.
