@@ -67,6 +67,11 @@ int main(int argc, char** argv)
     about.addAuthor(ki18nc("Fullname", "Guillaume DE BURE"), ki18nc("A job description", "Developer"), "guillaume.debure@gmail.com", ""
 #ifdef SKGKDE46ENABLED
                     , "willy9"
+#endif
+                   );
+    about.addAuthor(ki18nc("Fullname", "Siddharth SHARMA"), ki18nc("A job description", "Developer - Google Summer Of Code 2010"), "siddharth.kde@gmail.com", ""
+#ifdef SKGKDE46ENABLED
+                    , "h4xordood"
 #endif
                    );
     about.setOtherText(ki18nc("The description of the application", "The application name is inspired by Charles Dicken's tale <i>A Christmas Carol</i>, where the main character, Ebenezer Scrooge, a grumpy old narrow man, gets visited by three ghosts who change the way he sees the world, in a good way."));
